app.controller('cartCtrl', ['$scope', '$rootScope','$ionicHistory', '$timeout', 'cartFactory', 'orderService', 'userLocationFactory', 'userService', function($scope, $rootScope, $ionicHistory, $timeout, cartFactory, orderService, userLocationFactory, userService){
    $scope.radioContent = '';
    $scope.hasRadio = false;
    $scope.closeCartContent = '';
    $scope.closeCart = false;
    $scope.orderInfoIsV2 = (typeof orderListVersion) === 'function' && orderListVersion(appEnvironment) == 'v2';

    /**
     * 购物车，检验商品，检验促销，检验时间
     */
    $scope.onCart = function(){
        var communityId = window.localStorage.getItem('userCommunityId');
        var _param = {};
        var _items = cartFactory.getItems();
        var phone = userLocationFactory.user().phone;

        // 构造检验商品的json格式
        for(shopId in _items){
            var val = _items[shopId];
            var goodses = val.goodses||[];
            _param[shopId] = [];
            for(var i=0; i<goodses.length; i++){
                var goods = goodses[i];
                var _paramSku = {};
                _paramSku.skuId = goods.goodsSkuId;
                _paramSku.skuPrice = goods.goodsSkuPrice;
                _paramSku.skuPromotion = goods.goodsSkuPromotion;
                // _paramSku.preferenceId = goods.preferenceId;
                _param[shopId].push(_paramSku);
            }

        }

        orderService.checkShoppingCartNew(function(data){
            if(data.appServerStatus == 'close') {
                $scope.closeCart = true;
                $scope.closeCartContent = data.resultMsg;
                $scope.showAlertWindow($scope.closeCartContent);
            }
            cartFactory.validGoods(data.resultFlush);
            $scope.init();
            $scope.initCheck();
            $timeout(function(){
                $scope.hideLoading();
            }, 400);
        }, _param, phone, communityId);
    };

    // $rootScope.autoBackHtml = $timeout(function(){
    //     $ionicHistory.goBack();
    // }, 10*1000);
    $scope.cart = {
        items: {},
        totalMoney: 0,
        freight: 0,
        orderMoney: 0
    };
    $scope.canSubmit = false;
    $scope.chkAll = {}; //记录某shop是否全选

    $scope.selectedGroup = {}; //记录各shop中选中的商品

    $scope.chkWhole = true; //所有商品是否全选，默认true

    /**
     * 初始化选中状态， 默认为全部选中
     */
    $scope.initCheck = function(){
        angular.forEach($scope.cart.items, function(val, shopId){
            var list = [];
            angular.forEach(val.goodses, function(goods){
                goods.chk = true;
                this.push(goods);
            }, list);
            $scope.selectedGroup[shopId] = list;
            $scope.chkAll[shopId] = true;
        });
    };

    /**
     * 某shop中的某商品选中与否的操作
     */
    $scope.checkItem = function(shop, goods, chk){
        if(chk){
            arrayAddItem($scope.selectedGroup[shop], goods);
        }else{
            arrayRemoveItem($scope.selectedGroup[shop], goods);
        }
        $scope.chkAll[shop] = $scope.isCheckAll(shop);
    };

    /**
     * 某shop中的商品是否全部选中
     */
    $scope.isCheckAll = function(shop){
        return $scope.selectedGroup[shop].length == $scope.cart.items[shop].length;
    };

    /**
     * 某shop选中与否的操作
     */
    $scope.checkShop = function(shop, chk){
        angular.forEach($scope.cart.items[shop].goodses, function(goods){
            goods.chk = chk;
            $scope.checkItem(shop, goods, chk);
        });
    };

    /**
     * 全部商品选中与否的操作
     */
    $scope.checkWhole = function(){
        angular.forEach($scope.cart.items, function(goodsList, shop){
            $scope.checkShop(shop, $scope.chkWhole);
        });
    };


    /**
     * 页面初始化
     */
    $scope.init = function(){
        //console.log('cart init');
        userService.getServerTimeStamp(function(data){
            $scope.cart.items = cartFactory.getCartItems(data);
            $scope.cart.totalMoney = cartFactory.getTotalPromotionMoney();
            $scope.cart.freight = cartFactory.getFreight();
            $scope.cart.orderMoney = accAdd($scope.cart.totalMoney, $scope.cart.freight, 1);
            $scope.canSubmit = $scope.cart.orderMoney > 0 && $scope.getFreightSuccess();

            $scope.setShopInfo();
        });
    };

    /**
     * 减少操作
     * @param goods 购物车里的商品sku
     */
    $scope.minusQuantity = function(goods){
        cartFactory.minusQuantity(goods);
        $scope.init();
        $scope.$emit("changeCart");
    };

    /**
     * 增加操作
     * @param goods 购物车里的商品sku
     */
    $scope.plusQuantity = function(goods){
        if($scope.canPlus(goods)){
            cartFactory.plusQuantity(goods);
            $scope.init();
            $scope.$emit("changeCart");
        }
    };

    /**
     * 移除某店铺的商品
     * @param shop 店铺名称
     */
    $scope.deleteShop = function(shop){
        cartFactory.delItemsByKey(shop);
        $scope.init();
        $scope.$emit("changeCart");
    };

    /**
     * 删除购物车中的项目
     * @param goods 购物车里的商品sku
     */
    $scope.deleteGoods = function(goods){
        cartFactory.delItem(goods);
        $scope.init();
        $scope.$emit("changeCart");
    };

    /**
     * 展开/收起 配料
     */
    $scope.toggleIngredients = function(id){
        var dom = $dom('#'+id);
        var angularDom = angular.element(dom);
        angularDom.toggleClass('open');
    };

    /**
     * 展开/收起 赠品
     */
    $scope.toggleCartPromotionGift = function(id){
        var dom = $dom('#'+id);
        var angularDom = angular.element(dom);

        angularDom.toggleClass('open');
    };


    /**
     * 跳转生成订单页面
     */
    $scope.goOrderNew = function(){
    	$rootScope.orderCoupon = null;
        $rootScope.selectVoucherIds = {};
        $rootScope.scan = {};
        $rootScope.scanEmployee = {};
        $scope.toOrderCommit();
    };

    $scope.setShopInfo = function(){
        var data = cartFactory.getItems();

        for(shopId in data){
            var shopinfo = data[shopId]||{};
            var goodsList = shopinfo.goodses||[];
            if(goodsList.length){
                $scope.cart.items[shopId].hideShop = goodsList[0].hideShop;
            }
        }
    };

    /**
     * 去凑单，跳转
     * 如果与此“满”字号活动相关的SPU有大于0个，则跳转到这些商品的列表；
     * 反之，跳转到首页
     */
    $scope.goCustomProductList = function(data){
        var term = data.promotionTerm || {};
        console.log(term);
        if(term.promotionLinkSpu && term.promotionLinkSpu.length){
            $scope.toCustomProductList(term.promotionLinkSpu, '');
        }else{
            $scope.toHome();
        }
    };

    /**
     * 加载广播信息
     */
    $scope.loadRadioMsg = function(){
        orderService.orderRadio(function(msg){
            if(!msg){
                return;
            }
            var data = msg.resultTO;
            var str = '';
            for(var i=0; i<data.length; i++){
                var item = data[i];
                str += item.radioDescribe;
            }
            $scope.radioContent = str;
            $scope.hasRadio = data.length;
        }, 0);
    };


    $scope.getFreightSuccess = function() {
        if (typeof getFreight === 'function') {
            return true;
        }
        return false;
    };

    $scope.$on('cart-init', function(){
        $scope.showLoading('loading.html');
        $scope.loadRadioMsg();
        $scope.onCart();

    });
}]);
