app.controller('contactCtrl', ['$scope', '$ionicHistory', '$cordovaContacts', 'communalLocationFactory' , '$filter', function($scope, $ionicHistory, $cordovaContacts, communalLocationFactory, $filter) {
    var init = function() {
        var options = {};
        options.filter = "";
        options.multiple = true;
        options.fields = ["displayName", "name", "phoneNumbers"];
        if (navigator.contacts) {
            $cordovaContacts.find(options).then(function(result) {
                $scope.contactList = turnContactLevel(parseContact(result));
            }, function(err) {});
        }
    };

    /**
     * 将手机号变成二维数组，以拼音首字母开头
     */
    var turnContactLevel = function(contacts) {
        var result = [];
        for (var i = 0; i < contacts.length; i++) {
            var contact = contacts[i];
            var pre = (contact.pinyin||'')[0];
            var group = arrayGetItemByKey(result, 'pre', pre);
            if (!group) {
                group = {};
                group.pre = pre;
                group.contacts = [];
                result.push(group);
            }
            group.contacts.push(contact);
        }
        return result;
    };

    /**
     * 筛选手机号
     * @param contacts 手机号列表
     */
    var parseContact = function(contacts) {
        var result = [];
        if (contacts && contacts.length) {
            for (var i = 0; i < contacts.length; i++) {
                var phoneObj = {};
                if (mobileSystem == "android") {
                    phoneObj.name = contacts[i].displayName;
                    phoneObj.address = contacts[i].addresses;
                } else if (mobileSystem == "ios") {
                    phoneObj.name = contacts[i].name.formatted;
                    phoneObj.address = null;
                }

                phoneObj.pinyin = convertPinyin(phoneObj.name);

                var phoneNumber = contacts[i].phoneNumbers;
                if (phoneNumber != null && phoneNumber.length) {
                    for (var j = 0; j < phoneNumber.length; j++) {
                        var v = formatMobile(phoneNumber[j].value);
                        if (v != null) {
                            phoneObj.mobile = v;
                            result.push(phoneObj);
                        }
                    }
                }
            }
        }
        return result;
    };

    /**
     * 格式化手机号
     */
    var formatMobile = function(mobile) {
    	var _mobile = mobile.replace("+86", "").replace(/\D/g, "");
        if (checkMobile.test(_mobile)) {
            return _mobile;
        } else {
            return null;
        }
    };

    $scope.contactList = [];
    $scope.contact = {};
    // $scope.contactList = [
    //     {
    //         pre: 'z',
    //         contacts: [
    //             {name:'张接口',mobile:'15831287552',pinyin:'zhangjiekou',address:'横向北大街'},
    //             {name:'曾锅饭',mobile:'15831287556',pinyin:'zengguofan',address:'朝阳路'},
    //             {name:'正好',mobile:'15831287557',pinyin:'zhenghao'}
    //         ]
    //     },
    //     {
    //         pre: 'l',
    //         contacts: [
    //             {name:'李二蛋',mobile:'15831287551',pinyin:'lierdan'},
    //             {name:'李大那',mobile:'15831287553',pinyin:'lidana'}
    //         ]
    //     }

    // ];

    /**
     * 点击联系人时写入到页面
     * 判断本地存储中是否有信息，若果有，则重新写入新的联系人信息
     * 判断进入到地址新建页面之前的页面，如果有值，则重新写入原来的值
     */
    $scope.writeContact = function(contact){
        var o = communalLocationFactory.updateAddress.get("address_message_updateAddress")||{};
        o.contactPerson = contact.name || '';
        o.contactPhone = contact.mobile || '';
        o.addressContent = contact.address || o.addressContent;
        communalLocationFactory.updateAddress.put("address_message_updateAddress", o);
        var createAddressUrlSource = window.localStorage.getItem('createAddressUrlSource');
        $scope.toCreateAddress(createAddressUrlSource);
    };

    $scope.contactGoBack = function(){
        $ionicHistory.goBack();
    };
    
    $scope.onFocus = function(){
        $ionicScrollDelegate.scrollTo(0,0,true);
    };
    
    $scope.$on('contact-list-init', function() {
        init();
    });
}]);
