app.controller('orderListV2Ctrl', ['$scope', 'orderService', '$ionicSlideBoxDelegate', '$ionicPopup', 'paginationFactory', 'userLocationFactory', 'cartFactory', function($scope, orderService, $ionicSlideBoxDelegate, $ionicPopup, paginationFactory, userLocationFactory, cartFactory) {
    var pageObj = paginationFactory.init();
    $scope.orderScroll = true; //可以加载
    $scope.allOrderList = [];
    $scope.dataEnd = false; //加载完成
    $scope.dataEmpty = false;
    $scope.orderStatus = window.localStorage.getItem('orderStatus') || 'allOrder'; // allOrder | waitPay | waitDeliver | waitFetch | waitEvaluate
    window.localStorage.removeItem('orderStatus');
    /**
     * 加载全部订单
     */
    $scope.loadAllOrder = function() {
        if (!$scope.orderScroll) {
            return;
        }
        $scope.orderScroll = false;
        var userMobile = userLocationFactory.user().phone;
        // var userMobile = '13241115253';
        var orderStatus = $scope.orderStatus;

        orderService.queryOrderByOrderStatus(function(data) {
            if(data.length){
                $scope.allOrderList = $scope.allOrderList.concat(data);
            }

            $scope.dataEmpty = pageObj.getCurrentPage()==1 && data.length==0;
            $scope.dataEnd = data.length < pageObj.getPerPage();
            $scope.orderScroll = true;
            $scope.$broadcast('scroll.infiniteScrollComplete');

        }, userMobile, orderStatus, pageObj);
    };

    /**
     * 改变状态，加载订单
     * 清空原来的订单数据
     */
    $scope.changeStatus = function(status) {
        pageObj.setCurrentPage(1);
        $scope.orderStatus = status;
        $scope.allOrderList = [];
        $scope.loadAllOrder();
    };


    /**
     * 跳转到订单详情页面
     * @param  {Object} order 订单信息
     * @return
     */
    $scope.goOrderInfo = function(order) {
        // var orderId = order.orderId;
        var orderId = order.bossOrderNum;
        $scope.toOrderInfo(orderId);
    };

    /**
     * 取消订单
     * @param  {Object} order 订单信息
     * @return
     */
    $scope.cancelOrder = function(order) {
        $scope.showLoading('loading.html');
        var orderInfo = {
            orderId: order.orderId,
            orderStatus: 7
        };
        orderService.cancelOrder(function(data) {
            if (data && data == 1) {
                order.orderStatus = 7;
                // console.log('取消成功 ！！！');
            } else {
                $scope.showCancelOrderAlertWindow("取消订单失败，请联系荷粉客服。");
                // alert("取消订单失败");
            }
            $scope.hideLoading();
        }, orderInfo);
    };

    /**
     * 再来一单
     * @param  {Object} order 订单信息
     * @return
     */
    $scope.againOrder = function(order) {
        // $scope.showLoading('loading.html');
        var orderInfo = {
            orderId: order.orderId
        };
        orderService.againOrderGoodsInfo(function(data) {
            if (data.resultCode == "success") {
                $scope.emptyCart(); //清空购物车
                var goodsList = $scope.orderGoodsTurnCartGoods(data.resultTO);
                for (var i = 0; i < goodsList.length; i++) {
                    var goods = goodsList[i];
                    cartFactory.addItem(goods);
                }
                $scope.$emit("changeCart");
                $scope.toCart(true);
            }
            $scope.hideLoading();
        }, orderInfo);
    };

    /**
     * 投诉建议
     * @param  {Object} order 订单信息
     * @return
     */
    $scope.complain = function(order) {
        $scope.complainData = {};
        var html = '';

        html += '<p><textarea ng-model="complainData.response" placeholder="请输入您的意见或建议"></textarea></p>';
        html += '<p class="complain-phone"><a href="tel:4008236969"><small>客服电话：</small>400 823 6969</a></p>';
        $ionicPopup.show({
            title: '投诉建议',
            template: html,
            scope: $scope,
            cssClass: 'popup-complain',
            buttons: [{
                text: '取消',
                type: 'button-default',
                onTap: function(e) {
                    // 当点击时，e.preventDefault() 会阻止弹窗关闭。
                    // e.preventDefault();
                    return '';
                }
            }, {
                text: '确认',
                type: 'button-positive',
                onTap: function(e) {
                    // 返回的值会导致处理给定的值。
                    if ($scope.complainData.response) {
                        return $scope.complainData.response;
                    } else {
                        e.preventDefault();
                    }
                }
            }]
        }).then(function(res) {
            // console.log('你的意见是：', res);
            if (res) {

                var phone = userLocationFactory.user().phone;
                orderService.addComplain(function(data) {
                    var str = data.resultMsg || '提交失败，请稍候重试。';

                    $ionicPopup.alert({
                        title: '提示信息',
                        template: str,
                        okText: '知道了'
                    });
                }, phone, res, order.orderId);
            }
        });
        // console.log(order);
    };

    /**
     * 写评价
     * @param  {Object} order 订单信息
     * @return
     */
    $scope.goOrderEvaluate = function(order) {
        // console.log(JSON.stringify(order));
        var orderId = order.orderId;
        var shopBrandInfo = [];
        var _shopGoods = order.shopGoods || [];
        for (var i = 0; i < _shopGoods.length; i++) {
            var _shop = {
                shopBrandName: _shopGoods[i].shopBrandName,
                shopBrandId: _shopGoods[i].shopBrandId,
                shopBrandGoodsList: [{
                    goodsSpuName: _shopGoods[i].goodsName
                }]
            };
            shopBrandInfo.push(_shop);
        }
        var orderLogisticsInfo = order.orderLogisticsInfo || {};
        var logistorName = [];
        for (area in orderLogisticsInfo) {
            var logistor = orderLogisticsInfo[area] || '';
            logistorName.push(logistor.split('_')[0] || '');
        }
        var info = {
            shopBrandInfo: shopBrandInfo,
            orderId: orderId,
            logisticsPerson: logistorName.join(',')
        };

        var evaluateCacheInfo = new LocalStorageMap("evaluateInfo");
        evaluateCacheInfo.put("evaluateInfo", info);
        // console.log(JSON.stringify(info));
        $scope.toOrderEvaluate();
    };

    /**
     * 再次支付
     * @param  {Object} order 订单信息
     * @return
     */
    $scope.payAgain = function(order) {
        $scope.showLoading('loading.html');
        var orderId = order.orderId;
        var orderNum = order.orderNum;
        var orderMoney = order.orderPay;
        var orderInfo = {
            orderId: orderId
        };
        orderService.againOrderGoodsInfo(function(data) {
            if (data && data.resultCode == "success") {
                // console.log('再次支付：', order, data);
                var orderAddress = order.orderAddress;
                var goodsName = "";
                var goodsDescription = "";
                var goodsArray = [];
                for (var key in data.resultTO) {
                    goodsArray = goodsArray.concat(data.resultTO[key].singleGoods);
                }
                for (var j = 0; j < goodsArray.length; j++) {
                    if (j != 0) {
                        goodsName += "、";
                        goodsDescription += "、";
                    }
                    goodsName += goodsArray[j].goodsSpuName;
                    goodsDescription += goodsArray[j].goodsSpuName + "(" + goodsArray[j].goodsSkuName + ")X" + goodsArray[j].goodsNum
                }

                var onlinePayObj = {
                    orderNum: orderNum,
                    orderId: orderId,
                    goodsName: goodsName,
                    goodsDescription: goodsDescription,
                    price: orderMoney,
                    orderAddress: orderAddress
                };
                $scope.toOnlinePay(onlinePayObj);
            }
            $scope.hideLoading();
        }, orderInfo);
    };

    /**
     * 确认收货，完成订单
     * @param  {Object} order 订单信息
     * @return
     */
    $scope.finishOrder = function(order) {
        $scope.showLoading('loading.html');
        var orderInfo = {
            orderId: order.orderId,
            orderStatus: 4
        };
        orderService.updateOrder(function(data) {
            if (data && data == 1) {
                order.orderStatus = 4;
            } else {
                alert("确认订单失败");
            }
            $scope.hideLoading();
        }, orderInfo);
    };



    $scope.orderListGoBack = function() {
        var upOrderList = window.localStorage.getItem("beforeOrderList"); //获取跳转到订单详情页的上一页

        if (upOrderList && upOrderList == 'order-commit-v2') {
            $scope.toHome();
        } else {
            $scope.goBack();
        }
    };


    $scope.$on('order-list-v2-init', function() {
        // console.log('订单列表 V2 初始化了');
        //$scope.loadCurrentOrder();
        // $scope.loadHistoryOrder(); //调用当前订单列表之后会自动调用历史订单的调用，所以这里不用手动调用历史订单接口
        $scope.loadAllOrder();
    });
}]);
