/*
 * 全局方法，函数库
 */

/**
 * 比较版本
 */
var compareVersion = function() {
    var oldVersion = window.localStorage.getItem('appVersion') || '';
    if (oldVersion == '') {
        return true;
    }
    var newV = parseVersion(appVersion);
    var newVersionNum = newV.split('-')[1];
    var oldV = parseVersion(oldVersion);
    var oldVersionNum = oldV.split('-')[1];
    return parseInt(newVersionNum) > parseInt(oldVersionNum);
};

/**
 * 处理版本号
 */
var parseVersion = function(version) {
    var arrayVersion = version.split('.');
    var mainVersion = arrayVersion[0];
    var middleVersion = parseInt(arrayVersion[1]) <= 9 ? '0' + arrayVersion[1] : arrayVersion[1];
    var minVersion = parseInt(arrayVersion[2]) <= 9 ? '0' + arrayVersion[2] : arrayVersion[2];
    return mainVersion + middleVersion + minVersion;
};

/**
 * 当前应用环境
 * @return true 应用为荷粉到家
 * @return false 应用为荷粉校园
 */
var currentEnvironment = function () {
	if( appEnvironment == 'app' || appEnvironment == 'appWX' ){
		return true;
	}else if( appEnvironment == 'school' || appEnvironment == 'schoolWX' ){
		return false;
	}
};

/**
 * 获取商品图片
 * @param url string 三种图片地址合在一起的字符串
 * @param kind string 某种类型的图片 small | medium | big
 * @return 返回某种类型的商品图片
 */
var parseImgUrl = function(url, kind) {
    var urlImg = "./img/default.jpg";
    var urlArr = (url || '').split(';');
    for (var i = urlArr.length - 1; i >= 0; i--) {
        if (urlArr[i].indexOf(kind) > -1) {
            urlImg = "http://" + urlArr[i];
        }
    }
    return urlImg;
};

var parseImgUrlNew = function(url, kind) {
    var urlImg = "./img/default.jpg";

    for (var i = url.length - 1; i >= 0; i--) {
        if (url[i].indexOf(kind) > -1) {
            urlImg = "http://" + url[i];
        }
    }
    return urlImg;
};

var parseImgUrlFromArray = function(list){
    var urlImg = "./img/default.jpg";
    if(list.length == 0){
        return urlImg;
    }
    return 'http://'+list[0];
};

/**

 * 促销活动的类型转化为字符
 * @param type
 * @returns {Array}
 */
var promotionTypeToKey = function(type) {
    var result = [];
    var _type = JSON.parse(type);
    if (_type.length) {
        for (var i = 0; _type.length > i; i++) {
            result.push(promotionEnum[_type[i]]);
        }
    }
    return result;
};

var promotionTypeToKeyNew = function(data) {
    var promotionTypeList = [];
    for (promotionId in data) {
        var promotion = data[promotionId] || {};
        var _type = (promotion.promotionTerm || {}).promotionType;
        var _typeStr = promotionEnum[_type];
        if (promotionTypeList.indexOf(_typeStr) == -1) {
            promotionTypeList.push(_typeStr);
        }
    }
    return promotionTypeList;
};

var promotionTypeToKeyAndText = function(data) {

    var promotionTypeList = [];
    for (promotionId in data) {
        var promotion = data[promotionId] || {};
        var _type = (promotion.promotionTerm || {}).promotionType;
        var _typeStr = promotionEnum[_type];
        if (promotionTypeList.indexOf(_typeStr) == -1) {
            var ruleData = promotion.promotionTerm || {};
            ruleData.promotionId = promotion.promotionId;
            ruleData.promotionName = promotion.promotionName;
            var $rule = new PromotionRule(ruleData);
            var info = {
                img: _typeStr,
                text: $rule.promotionName
            };
            promotionTypeList.push(info);
        }
    }
    return promotionTypeList;
};

/**
 * 构造店铺列表页面的促销信息显示
 * @param  {list} list 促销信息的列表
 * @return {list}
 */
var parsePromotionForShopBrand = function(list){
    var result = [];
    if(list && list.length){
        for(var i = 0; i < list.length; i++){
            var promotion = list[i];
            var term = promotion.promotionTerm || {};
            term.promotionTypeImg = promotionEnum[term.promotionType];
            result.push(promotion);
        }
    }
    return result;
};

/**
 * 商品列表价格处理
 * @param goodsObj spu对象
 * @returns 对象包含3个参数  price:卖价;tPrice:促销价;noPrice:没有价格click事件参数
 */
var goodsPrice = function(goodsObj) {
    var showTPrice = "";
    var showPrice = "";
    var showPriceObj = {};
    var cartClose = "";
    var price = true;

    if (!goodsObj.goodsSpuPrice.originalPrice || goodsObj.goodsSpuPrice.originalPrice <= 0) {
        showTPrice = "暂无价格";
        price = false;
        cartClose = goodsObj.goodsSpuId;
    } else {
        if (goodsObj.goodsSpuPrice.promotionalPrice && goodsObj.goodsSpuPrice.promotionalPrice > 0) {
            showTPrice = goodsObj.goodsSpuPrice.promotionalPrice;
            showPrice = goodsObj.goodsSpuPrice.originalPrice;
        } else {
            showTPrice = goodsObj.goodsSpuPrice.originalPrice;
        }
    }

    showPriceObj['price'] = showPrice;
    showPriceObj['tPrice'] = showTPrice;
    showPriceObj['cart'] = cartClose;
    showPriceObj['havePrice'] = price;

    return showPriceObj;
};

/**
 * 格式化分类数据
 *
   [{
        "categoryFirstId": "1029",
        "categoryFirstName": "休闲零食",
        "categoryName": "营养保健",
        "count": 132,
        "categoryId": "1032",
        "categoryPName": "包装零食",
        "categoryPId": "1191"
    }, {
        "categoryFirstId": "1029",
        "categoryFirstName": "休闲零食",
        "categoryName": "方便速食",
        "count": 172,
        "categoryId": "1033",
        "categoryPName": "包装零食",
        "categoryPId": "1191"
    }, {
        "categoryFirstId": "1029",
        "categoryFirstName": "休闲零食",
        "categoryName": "进口休闲零食",
        "count": 24,
        "categoryId": "1034",
        "categoryPName": "进口包装零食",
        "categoryPId": "1192"
    }, {
        "categoryFirstId": "1029",
        "categoryFirstName": "休闲零食",
        "categoryName": "进口饼干,糕点",
        "count": 1,
        "categoryId": "1035",
        "categoryPName": "进口包装零食",
        "categoryPId": "1192"
    }]

    ==>

    [{
        categoryFirstId: 1029,
        categoryFirstName: "休闲零食",
        subCategoryList: [{
            categoryPId: 1192,
            categoryPName: "进口包装零食",
            subCategoryList: [
                {
                    categoryId: 1094,
                    categoryName: "进口保健滋养品",
                    count: 323
                },
                {
                    categoryId: 1095,
                    categoryName: "进口保健滋养品2",
                    count: 323

                }
            ]
        },{
            categoryPId: 1193,
            categoryPName: "纸包零食",
            subCategoryList: [
                {
                    categoryId: 1096,
                    categoryName: "大哥栗子",
                    count: 323
                },
                {
                    categoryId: 1097,
                    categoryName: "大馅包子",
                    count: 323

                }
            ]
        }]
    },{}]

 */
var parseCategory = function(data) {
    var result = [];
    for (var i = 0; i < data.length; i++) {
        var category = data[i];
        var hasFirstItem = arrayGetItemByKey(result, 'categoryFirstId', category.categoryFirstId);
        if (!hasFirstItem) {
            hasFirstItem = {
                categoryFirstId: category.categoryFirstId,
                categoryFirstName: category.categoryFirstName || '后台没给',
                subCategoryList: []
            };
            result.push(hasFirstItem);
        }
        var hasSecondItem = arrayGetItemByKey(hasFirstItem.subCategoryList, 'categoryPId', category.categoryPId);
        if (!hasSecondItem) {
            hasSecondItem = {
                categoryPId: category.categoryPId,
                categoryPName: category.categoryPName,
                subCategoryList: []
            };
            hasFirstItem.subCategoryList.push(hasSecondItem);
        }
        var hasThreeItem = arrayGetItemByKey(hasFirstItem.subCategoryList, 'categoryId', category.categoryPId);
        if (!hasThreeItem) {
            hasThreeItem = {
                categoryId: category.categoryId,
                categoryName: category.categoryName,
                count: category.count
            };
            hasSecondItem.subCategoryList.push(hasThreeItem);
        }
    };
    return result;
};

/**
 * 促销格式转换
 * @param info 服务器获取的促销{shopId:[{skuId,}],shopId:[]}
 */
var parsePromotionInfo = function(info){
    var result = [];
    for (var i = 0; i < info.length; i++) {
        var promotion = info[i];
        var promotionTerm = promotion['promotionTerm'] || {};
        var promotionTmp = hashExtend({}, promotion, promotionTerm);
        result.push(promotionTmp);
    };
    return result;
};
/*
 ********************** 关于dom操作 *************************************
 */
var $dom = function(selector) {
    var k = selector.slice(0, 1);
    var c = selector.slice(1);

    if (k == '#') {
        return document.getElementById(c);
    }
    if (k == '.') {
        return document.getElementsByClassName(c);
    }
};

var hasClass = function(obj, cls) {
    return obj.className.match(new RegExp('(\\s|^)' + cls + '(\\s|$)'));
};

var addClass = function(obj, cls) {
    if (!hasClass(obj, cls)) {
        obj.className += " " + cls;
    }
};

var removeClass = function(obj, cls) {
    if (hasClass(obj, cls)) {
        var reg = new RegExp('(\\s|^)' + cls + '(\\s|$)');
        obj.className = obj.className.replace(reg, ' ');
    }
};

var toggleClass = function(obj, cls) {
    if (hasClass(obj, cls)) {
        removeClass(obj, cls);
    } else {
        addClass(obj, cls);
    }
};

/**
 *********************** 荷粉页面阴影 ***************************
 */
var hfBackdrop = function(selector) {
    var dom = $dom(selector)[0];
    var _open = function() {
        addClass(dom, 'open');
    };
    var _close = function() {
        removeClass(dom, 'open');
    };
    var _toggle = function() {
        toggleClass(dom, 'open');
    };
    var api = {
        open: function() {
            _open();
        },
        close: function() {
            _close();
        },
        toggle: function() {
            _toggle();
        }
    };
    return api;
};
/**
 ************************* 手机、移动设备地理位置************************
 */
/* 获取 */
var getCurrentPosition = function(callback) {
    if (window.navigator.geolocation) {
        var geo = window.navigator.geolocation;
        geo.getCurrentPosition(function(position) {
            var lat = position.coords.latitude;
            var lon = position.coords.longitude;
            callback({
                lat: lat,
                lon: lon
            });
        }, function(error) {});
    } else {}
};

/**
## TODO
api = {

    getNetwork: function () {
      return navigator.connection.type;
    },

    isOnline: function () {
      var networkState = navigator.connection.type;
      return networkState !== Connection.UNKNOWN && networkState !== Connection.NONE;
    },

    isOffline: function () {
      var networkState = navigator.connection.type;
      return networkState === Connection.UNKNOWN || networkState === Connection.NONE;
    }
}
 */
var HefenConnection = function() {
    if (navigator.connection) {
        console.log(JSON.stringify(navigator.connection))
        var networkState = navigator.connection.type;
        return networkState !== Connection.UNKNOWN && networkState !== Connection.NONE;
    }
    return true;
};


/**
 *
 ******************************* js 数组方法扩展 *************************************
 *
 */

/**
 * 取得数组最小值
 * @param array
 * @returns
 */
var arrayMin = function(array) {
    return array.sort(function(a, b) {
        return a - b;
    })[0];
};

/**
 * 取得数组最大值
 * @param array
 * @returns
 */
var arrayMax = function(array) {
    return array.sort(function(a, b) {
        return b - a;
    })[0];
};

/**
 * 根据给定的值 删除数组的某项
 * @param array
 * @param item 给定的值
 * @return 删除某项后的数组
 */
var arrayRemoveItem = function(array, item) {
    var i = array.indexOf(item);
    if (i >= 0) {
        array.splice(i, 1);
    }
    return array;
};

/**
 * 添加数组项目，如果已存在则不在添加
 */
var arrayAddItem = function(array, item) {
    var i = array.indexOf(item);
    if (i < 0) {
        array.push(item);
    }
    return array;
};

/**
 * 通过key获取数组的项目 数组例如[{},{}]
 * @param array 所查询的数组
 * @param key 某个key值，通过此字段获取数组项目
 * @param val 与key所对应的值
 */
var arrayGetItemByKey = function(array, key, val) {
    for (var i = 0; i < array.length; i++) {
        var item = array[i];
        if (item[key] == val) {
            return item;
        }
    };
};

/**
 * 通过key删除商品
 * @param array
 * @param key
 * @param val
 * @private
 */
var arrayDeleteItemByKey = function(array, key, val) {
    for (var i = 0; i < array.length; i++) {
        var item = array[i];
        if (item[key] == val) {
            array.splice(i, 1);
        }
    };
};

/**
 * 数组对象排序
 */
var arraySort = function(array, attr, sort) {
    return array.sort(function(a, b) {
        switch (sort) {
            case 'asc':
                return a[attr] - b[attr];
                break;
            case 'desc':
                return b[attr] - a[attr];
                break;
            default:
        }
    });
};

/***************************** Hash {} 扩展方法 *********************************/
/**
 * 反转Hash
 * 交换 Hash 的 key 与 val
 */
var hashReverse = function(hash) {
    var _hash = {};
    for (var key in hash) {
        var val = hash[key];
        _hash[val] = key;
    }
    return _hash;
};

/**
 * 根据值获取key
 */
var hashGetKey = function(hash, val) {
    return hashReverse(hash)[val] || '';
};

/**
 * 扩展 合并Hash
 */
var hashExtend = function(targetObj){
    if(targetObj.constructor != Object){
        return {};
    }
    for (var i = 1; i < arguments.length; i++) {
        if(arguments[i].constructor == Object){
            for(k in arguments[i]){
                targetObj[k] = arguments[i][k];
            }
        }
    };
    return targetObj;
};

/**********浮点数的加减乘除开始**********/
/**
 * accAdd 加法, accSub 减法, accMul 乘法, accDiv 除法
 * @param {} arg1
 * @param {} arg2
 * @param {Number} scale    保留几位小数
 * @return {}
 */
var accAdd = function(arg1, arg2, scale) {
    var r1, r2, m;
    try {
        r1 = arg1.toString().split(".")[1].length;
    } catch (e) {
        r1 = 0
    }
    try {
        r2 = arg2.toString().split(".")[1].length;
    } catch (e) {
        r2 = 0
    }
    m = Math.pow(10, Math.max(r1, r2));
    var result = (arg1 * m + arg2 * m) / m;
    return scale ? result.toFixed(scale) : result;
};

var accSub = function(arg1, arg2, scale) {
    return accAdd(arg1, -arg2, scale);
};

var accMul = function(arg1, arg2, scale) {
    if (arg1 == 0) return 0;
    var m = 0,
        s1 = arg1.toString(),
        s2 = arg2.toString();
    try {
        m += s1.split(".")[1].length;
    } catch (e) {}
    try {
        m += s2.split(".")[1].length;
    } catch (e) {}
    var result = Number(s1.replace(".", "")) * Number(s2.replace(".", "")) / Math.pow(10, m);
    return scale ? result.toFixed(scale) : result;
};

var accDiv = function(arg1, arg2, scale) {
    var t1 = 0,
        t2 = 0,
        r1, r2;
    try {
        t1 = arg1.toString().split(".")[1].length;
    } catch (e) {}
    try {
        t2 = arg2.toString().split(".")[1].length;
    } catch (e) {}
    with(Math) {
        r1 = Number(arg1.toString().replace(".", ""));
        r2 = Number(arg2.toString().replace(".", ""));
        var result = (r1 / r2) * pow(10, t2 - t1);
        return scale ? result.toFixed(scale) : result;
    }
};
/**********浮点数的加减乘除结束**********/

/****************** 数学 **********************/
/**
 * 获取 n m 之间的随机数， n < m
 * @param min 小数
 * @param max 大数
 */
var getRandomNum = function(n, m) {
    var min = parseFloat(n);
    var max = parseFloat(m);
    var Range = max - min;
    var Rand = Math.random();
    return parseFloat((min + Rand * Range).toFixed(1));
}

/**
 * 获取随机 n 个字符
 * @param n 返回结果的个数
 */
var chars = ['0','1','2','3','4','5','6','7','8','9','A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z'];
var generateMixed = function(n) {
     var res = "";
     for(var i = 0; i < n ; i ++) {
         var id = Math.ceil(Math.random()*35);
         res += chars[id];
     }
     return res;
}
/****************** 数学 **********************/

/**
 * 判断该对象是否是为空   非空返回：true    空返回：false
 * @param {} obj
 * @return {Boolean}
 */
var existObj = function(obj) {
    if (typeof obj === "object" && !(obj instanceof Array)) {
        var hasProp = false;
        for (var key in obj) {
            hasProp = true;
            break;
        }
        if (hasProp) {
            obj = [obj];
        } else {
            //            throw "model.rows is empty object";
            hasProp = false;
        }
        return hasProp
    } else return false;
};


// var aesEncrypt = function(word, mkey){
//      var key = CryptoJS.enc.Utf8.parse(mkey);
//      var iv  = CryptoJS.enc.Utf8.parse('0102030405060708');
//      var srcs = CryptoJS.enc.Utf8.parse(word);
//      var encrypted = CryptoJS.AES.encrypt(srcs, key, { iv: iv,mode:CryptoJS.mode.CBC});
//      return encrypted.toString();
// }
// var aesDecrypt = function(word, mkey){
//      var key = CryptoJS.enc.Utf8.parse(mkey);
//      var iv  = CryptoJS.enc.Utf8.parse('0102030405060708');
//      var srcs = CryptoJS.enc.Utf8.parse(word);
//      var decrypt = CryptoJS.AES.decrypt(srcs, key, { iv: iv,mode:CryptoJS.mode.CBC});
//      return CryptoJS.enc.Utf8.stringify(decrypt).toString();
// }

var aesEncrypt = function(data, mkey){
    return Base64.encode(data);
}
var aesDecrypt = function(data, mkey){
    return Base64.decode(data);
}

/**********时间格式转换开始**********/
Date.prototype.format = function (format) {
    var o = {
        "M+": this.getMonth() + 1, //month
        "d+": this.getDate(), //day
        "h+": this.getHours(), //hour
        "m+": this.getMinutes(), //minute
        "s+": this.getSeconds(), //second
        "q+": Math.floor((this.getMonth() + 3) / 3), //quarter
        "S": this.getMilliseconds() //millisecond
    };
    if (/(y+)/.test(format)) format = format.replace(RegExp.$1,
        (this.getFullYear() + "").substr(4 - RegExp.$1.length));
    for (var k in o)if (new RegExp("(" + k + ")").test(format))
        format = format.replace(RegExp.$1,
            RegExp.$1.length == 1 ? o[k] :
                ("00" + o[k]).substr(("" + o[k]).length));
    return format;
};
/**
 * 返回剩余时间差，只返回最大的差数，3天5小时6秒 => 3天， 5小时6秒 => 5小时
 * @param {Int} time1 小的时间点
 * @param {Int} time2 大的时间点
 * @return 3天 | 5小时 | 8秒
 */
var timeDiff = function(time1, time2){
    if(time1 > time2){ return ''; }
    var diff = time2 - time1;

    //计算出相差天数
    var days = Math.floor(diff / (24 * 3600 * 1000));
    //计算出小时数
    var leave1 = diff % (24 * 3600 * 1000); //计算天数后剩余的毫秒数
    var hours = Math.floor(leave1 / (3600 * 1000));
    //计算相差分钟数
    var leave2 = leave1 % (3600 * 1000); //计算小时数后剩余的毫秒数
    var minutes = Math.floor(leave2 / (60 * 1000));
    //计算相差秒数
    var leave3 = leave2 % (60 * 1000); //计算分钟数后剩余的毫秒数
    var seconds = Math.round(leave3 / 1000);
    if(days){
        return days + '天';
    }
    if (hours) {
        return hours + '小时';
    }
    if(minutes){
        return minutes + '分钟';
    }
    if(seconds){
        return seconds + '秒';
    }

    // var result = '';
    // if(seconds){
    //     result = seconds + '秒';
    // }

    // if (minutes) {
    //     result = minutes + '分' + result;
    // }
    // if (hours) {
    //     result = hours + '小时' + result;
    // }
    // if (days) {
    //     result = days + '天' + result;
    // }
    // return result;

};
/**********时间格式转换开始*********/
/**
 * 处理首页特惠专区的数据
 * @param  {Array} list 原始数据
 * @return {Array}      已处理的数据
 */
var parsePreferenceData = function(list){

    var data = list || [];
    var localTime = (new Date()).getTime();
    for (var i = 0; i < data.length; i++) {
        var item = data[i];
        item.tipTime = timeDiff(localTime + item.diffTime, item.preferenceBeginTimeL);
        item.buyText = parsePreferenceBtnText(item);
        item.isStart = isPreferenceStart(item);
        item.isEnd = isPreferenceEnd(item);
    }
    return data;
};

var parsePreferenceBtnText = function(item){
    if(!isPreferenceStart(item)){
        return '即将开始';
    }
    if(isPreferenceEnd(item)) {
        return '已结束';
    }
    if(item.leftNumOne==0){
        return '已抢购';
    }

    return '购买';
};

/**
 * 特惠专区活动是否开始
 * @param  {Object}  item 数据
 * @return {Boolean}
 */
var isPreferenceStart = function(item){
    var now = (new Date()).getTime() + item.diffTime;
    return item.preferenceBeginTimeL <= now;
};
/**
 * 特惠专区活动是否结束
 * @param  {Object}  item 数据
 * @return {Boolean}
 */
var isPreferenceEnd = function(item){
    var now = (new Date()).getTime() + item.diffTime;
    return item.preferenceEndTimeL < now || item.preferenceStatus == 0;
};