/**
 * Cart Module
 *
 * 购物车模块
 * author wcl
 */
angular.module('Cart', [])
    .factory('cartFactory', function() {
        var _shoppingCartKey = "shoppingCart";
        var _shoppingCartCache = new LocalStorageMap(_shoppingCartKey);
        var _items = {};
        var _totalMoney = parseFloat(0);
        var _totalPromotionMoney = parseFloat(0);
        var _totalQuantity = 0;
        var _freight = 0;
        var _promotionTypeNum = hashReverse(promotionTypeEnum);


        // var _goodsMsg = {
        //     '-1': '商品已下架',
        //     '-2': '商品价格已修改',
        //     '-3': '店铺不在营业时间'
        // };

        /**
         * 初始化购物车
         * 主要初始 _items 变量
         * @private
         */
        var _init = function() {
            if (_shoppingCartCache.getKeys().length) {
                var shopIds = _shoppingCartCache.getKeys();
                //console.log('_items 已初始化 ', shopIds);
                for (var i in shopIds) {
                    var id = shopIds[i];
                    var shop = _shoppingCartCache.get(id);
                    _items[id] = shop;
                }

                // TODO
                // 检查商品
                _updateItems();
            }
        };
        var showInfo = function(goods, skuInfo) {
            var result = [];
            var msgList = skuInfo.skuMsg.split(',') || [];
            for (var i = 0; i < msgList.length; i++) {
                var msg = msgList[i].toString();
                if (msg && msg != '' && msg != 'null') {
                    var isShow = ['0', '1', '4'].indexOf(skuInfo.skuStatus.toString()) > -1 ? 0 : 1;
                    result.push([msg, isShow]);
                }
            }
            return result;
        }
        var noShowInfo = function(goods, skuInfo) {
                return [];
            }
            /**
             * 更新商品、重新写入缓存
             * 根据最新信息，更新sku自身的属性 canSale tipMsg cPrice unitCPrice
             * 计算出全局的商品数量
             * @private
             */
        var _updateItems = function() {
            var skuErrorMap = {
                '-4': showInfo,
                '-3': showInfo,
                '-1': showInfo,
                '0': showInfo,
                '1': showInfo,
                '2': noShowInfo,
                '3': showInfo,
                '4': showInfo,
                '5': showInfo,
                '6': showInfo
            };
            var _money = 0;
            var _quantity = 0;
            for (var shopId in _items) {
                var _data = _items[shopId];
                if (_data) {
                    var _goodses = _data.goodses || [];
                    for (var i in _goodses) {
                        var goods = _goodses[i];

                        // 定义需要操作且需要服务器返回的数据，
                        // 这些字段值会赋值到每个购物车的商品上，再使用这些字段值进行加减钱
                        var skuPrice = parseFloat(goods.goodsSkuPrice).toFixed(1);

                        // 2016.05.31，特惠商品，会把商品的goodsSkuPromotionPrice赋值为特惠价格
                        // 此代码作废，不能使用，切记不能使用促销价，会减两次
                        // if(goods.goodsSkuPromotionPrice && goods.goodsSkuPromotionPrice > 0){
                        //     skuPrice = parseFloat(goods.goodsSkuPromotionPrice).toFixed(1);
                        // }
                        var preferenceId;
                        var leftNumOne = goods.leftNumOne || -1;
                        var canSale = true;
                        var tipMsg = [];

                        var rules = goods.goodsSkuPromotion || [];
                        rules = parsePromotionInfo(rules);

                        // 2016.06.22 运费改版，运费5元，商户承担部分运费，用户承担部分运费
                        // 在购物车数据校验之前，运费为0，规则为{}
                        // 在购物车数据校验之后，运费为 shopBrandFreight ，规则为 shopBrandFreightReduce
                        var shopBrandFreight = 0;
                        var shopBrandFreightReduce = {};

                        // 2016.07.15 自营商品 提示配送时间
                        var shopNotice = '';

                        var skuInfo = (GOODS_PROMOTION_RULE[shopId] || {})[goods.goodsSkuId];
                        // console.log('验证数据：',skuInfo);
                        if (skuInfo) {

                            // 更新最新的商品价格
                            skuPrice = parseFloat(skuInfo.skuPrice).toFixed(1);

                            // 验证商品能够购买
                            // skuStatus大于0时，才能正常购买
                            // 如果不能购买，购物车中的商品有遮罩，并且显示错误信息，价格不计算在合计中
                            canSale = skuInfo.skuStatus >= 0;
                            tipMsg = skuErrorMap[skuInfo.skuStatus](goods, skuInfo);

                            // 验证促销信息，
                            // 如果有促销信息，更正价格，并重新计算合计
                            // 如果有像没有促销信息，使用原价
                            rules = skuInfo['promotions'] || [];

                            // 2016.05.19 首页特惠专区所用
                            leftNumOne = skuInfo.leftNumOne >= 0 ? skuInfo.leftNumOne : -1;
                            preferenceId = skuInfo.preferenceId;

                            //2016.06.22  运费改版
                            shopBrandFreight = skuInfo.shopBrandFreight || 0;
                            shopBrandFreightReduce = skuInfo.shopBrandFreightReduce || {};

                            //2016.07.15
                            shopNotice = skuInfo.hefenOverTimeNotice || '';
                        }

                        // console.log(JSON.stringify(skuInfo));
                        // console.log(JSON.stringify(goods));
                        // 重置所有字段初始值，以为减钱做准备
                        // console.log('sku价格：', skuPrice);
                        goods.goodsSkuPrice = skuPrice;
                        goods.canSale = canSale;
                        goods.tipMsg = tipMsg;
                        goods.goodsSkuPromotion = rules;
                        goods.leftNumOne = leftNumOne;
                        goods.preferenceId = preferenceId;

                        goods.goodsPrice = accAdd(skuPrice, goods.iPrice, 1);
                        goods.cPrice = accMul(goods.goodsPrice, goods.cNum, 1);

                        //2016.06.22  运费改版
                        goods.shopBrandFreight = shopBrandFreight;
                        goods.shopBrandFreightReduce = shopBrandFreightReduce;

                        //2016.07.15
                        goods.shopNotice = shopNotice;

                        // 挂载商品扫码，减钱
                        // goodsSkuScanLimit 为 0 时，不限制数量，
                        // 大于 0 时，限制数量，购物数量 cNum 超过此值时，按 goodsSkuScanLimit 计算
                        _mountScanCode(goods);

                        // 挂载促销活动，减钱
                        // 直降 折扣 单品满减
                        _mountPromotion(goods);

                        // 2016.05.31 特惠商品如果限制的处理
                        _mountPreference(goods);

                        //if(goods.canSale){
                        _money += parseFloat(goods.cPrice);
                        //}

                        _quantity += 1;
                    }

                    _updateLocalStorage(shopId, _data);
                }
            }
            _totalQuantity = _quantity; // 计算全局的商品数量
            _totalMoney = _money; // 计算出金额
        };

        /**
         * 更新本地缓存
         * @param shopId 购物车缓存的key值，这里是店铺Id
         * @param data   购物车缓存key的数据
         * @private
         */
        var _updateLocalStorage = function(shopId, data) {
            _shoppingCartCache.put(shopId, data);
            //console.log('已写入本地缓存');
        };

        /**
         * 商品促销规则封装
         * 如果促销信息为空，则cPrice为原价 oPrice为0
         * 有折扣或直降，还有单品满减/单品满赠，首先先计算折扣或直降，再计算单品满减/单品满赠
         * 利用单品原价(goodsPrice包含配料)更新sku的单品金额(cPrice)、单品单价(unitCprice)、提示信息(tipMsg包括促销信息、错误信息)
         * @param goods 某个商品sku
         */
        var _mountPromotion = function(goods) {
            var rules = goods.goodsSkuPromotion;

            var singleRule, groupRule;
            for (var i = 0; i < rules.length; i++) {
                var rule = rules[i];
                if (rule.promotionType == _promotionTypeNum['zhijiang'] || rule.promotionType == _promotionTypeNum['zhekou']) {
                    singleRule = rule;
                }
                if (rule.promotionType == _promotionTypeNum['danpin_manjian'] || rule.promotionType == _promotionTypeNum['danpin_manzeng']) {
                    groupRule = rule;
                }
            }

            if (singleRule) {
                // 这里是影响商品单个的促销，计算优惠时传入单价 goods.goodsPrice
                var $rule = new PromotionRule(singleRule);
                var msg = $rule.toPromotionMessage();
                var price = $rule.getPromotionPrice(goods.goodsPrice, goods.cNum); // 获取应该减的金额，goods.cPrice减去此值

                goods.cPrice = accSub(goods.cPrice, price, 1);
                // goods.cPrice = price;
                // goods.unitCPrice = accDiv(price, goods.cNum, 1);
                // goods.goodsSkuPromotionPrice = goods.unitCPrice;
                //if(goods.canSale){
                goods.tipMsg.push([msg, 1]);
                //}
            }

            if (groupRule) {
                // 这里是影响商品总计的促销，计算优惠时传入此商品乘数量后的金额 goods.cPrice
                var $rule = new PromotionRule(groupRule);
                var msg = $rule.toPromotionMessage();
                var price = $rule.getPromotionPrice(goods.cPrice, goods.cNum); // 获取应该减的金额，goods.cPrice减去此值

                goods.cPrice = accSub(goods.cPrice, price, 1);
                //if(goods.canSale){
                goods.tipMsg.push([msg, 1]);
                //}
            }
        };

        /**
         * 扫码优惠
         */
        var _mountScanCode = function(goods) {
            if (goods.goodsSkuScanDown) {
                var scanNum = goods.goodsSkuScanLimit == -1 ? goods.cNum : Math.min(goods.goodsSkuScanLimit, goods.cNum);
                var price = goods.goodsSkuScanDown * scanNum; // 获取应该减的金额，goods.cPrice减去此值
                goods.cPrice = accSub(goods.cPrice, price, 1);
                var tipScan = '';
                if (goods.goodsSkuScanLimit != -1) {
                    tipScan = '(限' + goods.goodsSkuScanLimit + '件)';
                }
                var tip = ['扫码优惠' + goods.goodsSkuScanDown + '元 已优惠' + (goods.goodsSkuScanDown * scanNum).toFixed(1) + '元' + tipScan, 1];
                goods.tipMsg.push(tip);
            }
        };

        var _mountPreference = function(goods){
            if(goods.leftNumOne == 0){
                goods.canSale = false;
            }
            if(goods.leftNumOne > 0){
                if(goods.cNum > goods.leftNumOne){
                    _updateOldItem(goods, goods.leftNumOne);
                    _updateItems();
                }
            }
        };

        /**
         * 获取符合购物车页面的格式化后的数据
         * 根据最新促销规则，重新计算价格、金额
         * sku自身信息已是最新，这里是计算店铺促销 店铺金额
         * @return 数据
         * @example
         * {
         *   shopId: {
         *       name: '店铺名称111',
         *       groupGoods: { //这里是组合商品 合计满减/合计满赠的商品
         *          133: {
         *              name: '满100，减10元',
         *              goodses: [],
         *              promotionTerm: {},
         *              money: 0,
         *              msg: '再买15元，达到100元，可优惠10元'|'现在123元，已优惠10元',
         *              giftList: []
         *          },
         *          144: {
         *              name: '满100，减15元',
         *              goodses: [],
         *              promotionTerm: {},
         *              money: 0,
         *              msg: '再买15元，达到100元，可优惠15元'|'现在123元，已优惠15元',
         *              giftList: []
         *          },
         *          155: {
         *              name: '满100，有赠品',
         *              goodses: [],
         *              promotionTerm: {},
         *              money: 0,
         *              msg: '再买15元，达到100元，有赠品'|'现在123元，可领取赠品'
         *              giftList: [{id:111,name:'aaa',num:2,type:0}]
         *          }
         *       },
         *       singleGoods: [ //这里是非组合商品，包括有促销、无促销
         *           {cNum:1,cPrice:12,goodsSkuId:24373,...},
         *           {}
         *       ],
         *       shopMoney: 0,
         *       shopGoodsLength: 0
         *   }
         * }
         * 促销规则 {
         *    shopId: {
         *        skuId: {
         *            status: -1|-2|-3,
         *            promotions: [
         *                {promotionId: 222, promotionType: 1, promotionName: '直降', priceDown: 2},
         *                {promotionId: 333, promotionType: 2, promotionName: '折扣', discount: 5},
         *                {promotionId: 444, promotionType: 3, promotionName: '单品满减', priceReach: 100, priceDown: 10},
         *                {promotionId: 555, promotionType: 4, promotionName: '合计满减', priceReach: 100, priceDown: 10},
         *                {promotionId: 666, promotionType: 5, promotionName: '合计满赠', priceReach: 100, giftList: [{}]},
         *                {promotionId: 777, promotionType: 6, promotionName: '单品满赠', priceReach: 100, giftList: [{}]},
         *            ]
         *        }
         *    }
         * }
         * @param  data 服务器当前时间的时间戳
         * @private
         */
        var _getCartItems = function(data) {
            var _tmpTotalMoney = 0;
            var result = {};
            for (var shopId in _items) {
                var shop = _items[shopId];
                if (shop) {
                    var _shopMoney = 0;
                    var _shopGoodsLength = 0;
                    var _goodses = shop.goodses || [];
                    var _groupGoods = {};
                    var _singleGoods = [];
                    var _groupDownTotal = 0; // 第二版 为了显示某个店铺的满减总共减了多少钱而设置此变量
                    // 2016.06.22 运费改版
                    var _shopBrandFreight, _shopBrandFreightReduce;

                    //2016.07.15
                    var _shopNotice;

                    for (var i = 0; i < _goodses.length; i++) {
                        var goods = _goodses[i];
                        var skuInfo = (GOODS_PROMOTION_RULE[shopId] || {})[goods.goodsSkuId];

                        // console.log('购物车商品', goods);
                        _shopBrandFreight = goods.shopBrandFreight;
                        _shopBrandFreightReduce = goods.shopBrandFreightReduce;

                        _shopNotice = goods.shopNotice;

                        var _currentGroupPromotion = _hasGroupPromotion(skuInfo);
                        if (_currentGroupPromotion) {
                            if (!_groupGoods[_currentGroupPromotion.promotionId]) {
                                var $rule = new PromotionRule(_currentGroupPromotion);
                                //var msg = $rule.toPromotionMessage();
                                var msg = $rule.promotionMessage;

                                _groupGoods[_currentGroupPromotion.promotionId] = {};
                                _groupGoods[_currentGroupPromotion.promotionId]['goodses'] = [];
                                _groupGoods[_currentGroupPromotion.promotionId]['name'] = msg;
                                _groupGoods[_currentGroupPromotion.promotionId]['promotionTerm'] = _currentGroupPromotion;
                                _groupGoods[_currentGroupPromotion.promotionId]['money'] = 0;
                                _groupGoods[_currentGroupPromotion.promotionId]['msg'] = '';
                                _groupGoods[_currentGroupPromotion.promotionId]['msgPill'] = '';
                            }
                            _groupGoods[_currentGroupPromotion.promotionId]['goodses'].push(goods);
                            if (goods.canSale) {
                                _groupGoods[_currentGroupPromotion.promotionId]['money'] += parseFloat(goods.cPrice);
                            }
                            //console.log('goods',goods.goodsSkuId, _currentGroupPromotion , msg);
                        } else {
                            _singleGoods.push(goods);
                            if (goods.canSale) {
                                _shopMoney = _shopMoney + parseFloat(goods.cPrice);
                            }
                        }
                        if (goods.canSale) {
                            _shopGoodsLength += 1;
                        }
                    }
                    for (groupId in _groupGoods) {
                        var _group = _groupGoods[groupId];
                        var _money = _getGroupPromotionMoney(_group);
                        var _msg = _getGroupPromotionMsg(_group);
                        var _giftList = _getGroupPromotionGift(_group);
                        _group['moneyOrg'] = _group['money'];
                        _group['money'] = _money;
                        _group['msg'] = _msg;
                        _group['msgPill'] = promotionTypeCnEnum[_group['promotionTerm']['promotionType']];
                        _group['giftList'] = _giftList;
                        _shopMoney += parseFloat(_money);
                        _groupDownTotal = accAdd(_groupDownTotal, accSub(_group['moneyOrg'], _group['money'], 1), 1);
                    }

                    result[shopId] = {};
                    result[shopId]['groupGoods'] = _groupGoods;
                    result[shopId]['singleGoods'] = _singleGoods;
                    result[shopId]['name'] = shop.name;
                    result[shopId]['shopMoney'] = _shopMoney;
                    result[shopId]['shopGoodsLength'] = _shopGoodsLength;
                    result[shopId]['deliveryTip'] = _getSendTip(shopId, shop, data);
                    result[shopId]['groupDownTotal'] = _groupDownTotal;

                    result[shopId]['shopBrandFreight'] = _shopBrandFreight;
                    result[shopId]['shopBrandFreightReduce'] = _shopBrandFreightReduce;

                    result[shopId]['shopNotice'] = _shopNotice || '';

                    _tmpTotalMoney = accAdd(_tmpTotalMoney, _shopMoney, 1);
                }
            }
            // _getOrderFreight(result); //这里是第一版运费，只返回一个总运费的数值
            _totalPromotionMoney = _tmpTotalMoney;


            // 2016.04.26 第二版，运费随之改版
            var freightObj = _getOrderFreightNew(result);
            // console.log(freightObj);
            _freight = freightObj.total;

            for(shopId in result){
                var shopsFreight = freightObj.shops || {};
                var shopsFreightTip = freightObj.shopsFreightTip || {};
                var tip = shopsFreightTip[shopId] || {};
                result[shopId]['freight'] = shopsFreight[shopId];
                result[shopId]['shopMoney'] = accAdd(result[shopId]['shopMoney'], shopsFreight[shopId], 1);
                if(tip['useFreightV3']){
                    result[shopId]['freightShop'] = result[shopId]['shopBrandFreight'] - shopsFreight[shopId];
                    result[shopId]['freightTip'] = tip['msg']||'';
                    result[shopId]['freightStyle'] = tip['style']||{};
                    result[shopId]['freightUseRule'] = tip['freightUseRule']||{};
                }
                if(!tip['useFreightV3']){
                    delete result[shopId]['shopBrandFreight'];
                }
            }
            return result;
        };

        /**
         * 获取是否有组合促销活动，有,返回促销活动，没有，返回false
         * @param data 促销信息
         */
        var _hasGroupPromotion = function(data) {
            // console.log('_hasGroupPromotion',data);
            if (data && data.promotions.length) {
                var downGroupPromotion = _getItemByKey(data.promotions, 'promotionType', _promotionTypeNum['heji_manjian']);
                var giftGroupPromotion = _getItemByKey(data.promotions, 'promotionType', _promotionTypeNum['heji_manzeng']);
                var downMeiGroupPromotion = _getItemByKey(data.promotions, 'promotionType', _promotionTypeNum['mei_manjian']);
                var giftMeiGroupPromotion = _getItemByKey(data.promotions, 'promotionType', _promotionTypeNum['mei_manzeng']);
                if (downGroupPromotion) {
                    return downGroupPromotion;
                }
                if (giftGroupPromotion) {
                    return giftGroupPromotion;
                }
                if (downMeiGroupPromotion) {
                    return downMeiGroupPromotion;
                }
                if (giftMeiGroupPromotion) {
                    return giftMeiGroupPromotion;
                }
            }
            return false;
        };

        /**
         * 获得组合促销活动的，降价后的金额
         * @param data 促销信息
         */
        var _getGroupPromotionMoney = function(data) {

            var result = data['money'] || 0;
            var _reach = data['promotionTerm']['priceReach'] || 0;
            var _down = data['promotionTerm']['priceDown'] || 0;
            if (result >= _reach) {
                if (data['promotionTerm']['promotionType'] == _promotionTypeNum['mei_manjian']) {
                    var _reachNum = parseInt(result / _reach);
                    _down = _reachNum * _down;
                    result = accSub(result, _down, 1);
                }
                if (data['promotionTerm']['promotionType'] == _promotionTypeNum['heji_manjian']) {
                    result = accSub(result, _down, 1);
                }
            }
            return parseFloat(result);
        };

        /**
         * 获得组合促销活动的介绍
         * @param data 促销信息
         */
        var _getGroupPromotionMsg = function(data) {

            var result = '';
            var _money = data['money'] || 0;
            var _reach = data['promotionTerm']['priceReach'] || 0;
            var _diff = Math.abs(parseFloat(accSub(_money, _reach, 1)));
            if (_money >= _reach) {
                return '您已享受“' + data.name + '”活动';
            } else {
                return '再买' + _diff + '元，可享受“' + data.name + '”活动';
            }
            return '';
        };

        /**
         * 获得组合促销活动的赠品以及数量，如果是有赠品的活动
         * @param data 促销信息
         */
        var _getGroupPromotionGift = function(data) {

            var _money = data['money'] || 0;
            var _reach = data['promotionTerm']['priceReach'] || 0;
            var num = 0;
            if (_money >= _reach) {

                if (data['promotionTerm']['promotionType'] == _promotionTypeNum['heji_manzeng']) {
                    num = 1;
                }
                if (data['promotionTerm']['promotionType'] == _promotionTypeNum['mei_manzeng']) {
                    num = parseInt(_money / _reach);
                }
            }
            var result = [];
            if (data['promotionTerm']['giftList']) {
                for (var i = 0; i < data['promotionTerm']['giftList'].length; i++) {
                    var gift = data['promotionTerm']['giftList'][i];
                    gift.num = num;
                    result.push(gift);
                };
            }
            return result;
        };

        /**
         * 获取运费，如果获取失败，返回0
         * @param data 包含金额的数据，以店铺id分组
         */
        var _getOrderFreight = function(data) {
            if (typeof getFreight === 'function') {
                _freight = getFreight(data);
            } else {
                _freight = 0;
            }
        };

        /**
         * 获取运费，如果获取失败，返回0
         * @param data 包含金额的数据，以店铺id分组
         * @return {Object}  运费对象 {total:0,shops:{id1:3,id2:0}}
         */
        var _getOrderFreightNew = function(data) {
            if (typeof getFreight === 'function') {
                var version = '';
                if((typeof orderListVersion) === 'function'){
                    version = orderListVersion(appEnvironment) || '';
                }
                return getFreight(data, version);
            } else {
                return {total:0};
            }
        };

        /**
         * 获取订单配送时间的提示
         * @param  {String} shopBrandId 供货商ID
         * @param  {Object} shopBrand   商品信息
         * @param  {int} data           当前服务器时间
         * @return {Object}
         */
        var _getSendTip = function(shopBrandId, shopBrand, data){
            if (typeof getSendTip === 'function') {
                return getSendTip(shopBrandId, shopBrand, data, appEnvironment);
            } else {
                return {};
            }
        };

        /**
         * 通过key获取数组的项目 数组例如[{},{}]
         * @param array 所查询的数组
         * @param key 某个key值，通过此字段获取数组项目
         * @param val 与key所对应的值
         */
        var _getItemByKey = function(array, key, val) {
            for (var i = 0; i < array.length; i++) {
                var item = array[i];
                if (item[key] == val) {
                    return item;
                }
            };
        };

        /**
         * 通过key删除商品
         * @param array
         * @param key
         * @param val
         * @private
         */
        var _deleteItemByKey = function(array, key, val) {
            for (var i = 0; i < array.length; i++) {
                var item = array[i];
                if (item[key] == val) {
                    array.splice(i, 1);
                }
            };
        };

        /**
         * 获取店铺商品
         * @param shop
         * @returns {*|Array}
         * @private
         */
        var _getShopGoods = function(shopId) {
            var _data = _items[shopId] || {};
            return _data.goodses || [];
        };

        /** 第一版，获取已存在商品，不考虑sku、配料 **/
        // var _getShopGoodsById = function(item){
        //     var goodses = _getShopGoods(item.goodsSpuBrandName);
        //     return _getItemByKey(goodses, 'goodsSpuId', item.goodsSpuId);
        // };
        var _getShopGoodsById = function(item) {
            var shopId = item.goodsSpuShopBrandId;
            if (item.goodsSpuType == 0) {
                //自营商品，shopId变成0
                shopId = SELF_SHOP_ID;
            }
            var goodses = _getShopGoods(shopId);
            for (var i = 0; i < goodses.length; i++) {
                var goods = goodses[i];
                // console.log('goodsSkuId', goods.goodsSkuId, ': itemSkuId', item.goodsSkuId);
                // console.log(goods.searchKey, item.searchKey, angular.equals(goods.searchKey, item.searchKey));
                if (goods.goodsSkuId == item.goodsSkuId && angular.equals(goods.searchKey, item.searchKey)) {
                    return goods;
                }
            };
        };

        /**
         * 购物车新增商品
         * @param item
         * @private
         */
        var _addNewItem = function(item) {
            var shopId = item.goodsSpuShopBrandId;
            var shopName = item.goodsSpuShopBrandName;
            if (item.goodsSpuType == 0) {
                //自营商品，shopId变成0
                shopId = SELF_SHOP_ID;
                shopName = SELF_SHOP_NAME;
            }
            var goodses = _getShopGoods(shopId);
            goodses.push(item);
            _items[shopId] = {
                name: shopName,
                goodses: goodses
            };
        };

        /**
         * 更新老商品
         * @param item
         * @param cNum
         * @private
         */
        var _updateOldItem = function(item, cNum) {
            item.cNum = cNum;
            // item.cPrice = accMul(item.unitCPrice, cNum, 1);
            // item.oPrice = accMul(item.unitOPrice, cNum, 1);
        };

        /**
         * 更新扫码信息
         * @param item 已存在购物车的商品
         * @param newItem 当前加入购物车的商品信息
         * 此方法只会在更新购物车某商品时调用，只用于更新扫码信息
         */
        var _updateOldItemForScan = function(item, newItem) {
            item.goodsSkuScanDown = Math.max(newItem.goodsSkuScanDown, item.goodsSkuScanDown);
            item.goodsSkuScanLimit = Math.max(newItem.goodsSkuScanLimit, item.goodsSkuScanLimit);
        };

        /**
         * 删除商品
         * @param item
         * @private
         */
        var _deleteItem = function(item) {

            var shopId = item.goodsSpuShopBrandId;
            if (item.goodsSpuType == 0) {
                shopId = SELF_SHOP_ID;
            }
            var goodses = _getShopGoods(shopId);

            _deleteItemByKey(goodses, 'searchStr', item.searchStr);

            if (goodses.length > 0) {
                _items[shopId].goodses = goodses;
            } else {
                _deleteShop(shopId);
            }
        };

        /**
         * 删除店铺
         * @param shop
         * @private
         */
        var _deleteShop = function(shopId) {
            delete _items[shopId];
            _shoppingCartCache.remove(shopId);
        };

        /**
         * 清空购物车
         * @private
         */
        var _emptyCart = function() {
            for (var shopId in _items) {
                _shoppingCartCache.remove(shopId);
            }
            _items = {};
        };

        /**
         * 外部调用购物车的接口
         */
        var api = {
            getItems: function() {
                return _items;
            },
            getCartItems: function(data) {
                return _getCartItems(data);
            },
            getItemsList: function() {
                var goodses = [];
                for (key in _items) {
                    goodses = goodses.concat(_items[key].goodses);
                };
                return goodses;
            },
            getTotalMoney: function() {
                return _totalMoney;
            },
            getTotalPromotionMoney: function() {
                return _totalPromotionMoney;
            },
            getTotalQuantity: function() {
                return _totalQuantity;
            },
            getFreight: function() {
                return _freight;
            },
            addItem: function(item) {
                // console.log('--> new cart goods: ', JSON.stringify(item));
                // console.log('==> _items:', JSON.stringify(_items));
                var searchKey = {}; // 记录配料的id和数量，与sku的id一起配合，判断加入购物车的商品是否已存在
                var searchStr = '' + item.goodsSkuId; // 用于删除商品sku时，确定的唯一值
                angular.forEach(item.ingredientsInfo, function(val, key) {
                    searchKey[item.goodsSkuId + '_' + val.ingredientsId] = val.num;
                    searchStr += '_' + val.ingredientsId + '_' + val.num;
                });
                item.searchKey = searchKey;
                item.searchStr = searchStr;

                item.ingredientsLength = Object.keys(item.ingredientsInfo).length; //商品的配料长度，用于购物车页面，配料在2个以上时，显示更多按钮
                // item.canSale = true;           // 商品是够可以售卖，默认为true
                // item.tipMsg = [];              // 商品的提示信息

                var oldItem = _getShopGoodsById(item);

                if (oldItem) {
                    // 2016.06.02特惠商品功能之前，每次都在原来的基础上增加。
                    // var q = oldItem.cNum + item.cNum;
                    // 2016.06.02特惠商品功能之后，覆盖原来数量
                    var q = item.cNum;
                    _updateOldItem(oldItem, q);
                    _updateOldItemForScan(oldItem, item);
                } else {
                    _addNewItem(item);
                }
                // console.log('++> _items:', JSON.stringify(_items));
                _updateItems();
            },
            delItem: function(item) {
                _deleteItem(item);
                _updateItems();
            },
            delItemsByKey: function(key) {
                _deleteShop(key);
                _updateItems();
            },
            emptyCart: function() {
                _emptyCart();
                _updateItems();
            },
            plusQuantity: function(item) {
                if( !item.leftNumOne || (item.leftNumOne && (item.leftNumOne > item.cNum || item.leftNumOne == -1))){
                    var cNum = item.cNum + 1;
                    _updateOldItem(item, cNum);
                    _updateItems();
                }else{
                    // console.log('不能加了');
                }

            },
            minusQuantity: function(item) {
                var cNum = item.cNum - 1;
                if (cNum > 0) {
                    _updateOldItem(item, cNum);
                } else {
                    _deleteItem(item);
                }
                _updateItems();
            },
            validGoods: function(validInfo) {
                // validInfo = {
                //     "0": {
                //         12491: {
                //             skuMsg: "哈哈哈",
                //             skuPrice: 12,
                //             skuStatus: 2,
                //             promotions: [
                //                 {promotionName:'2016新年大促销',promotionId:123,promotionType:1, priceDown:1.2, limitNum:4},
                //                 {promotionName:'新年满减大促销',promotionId:124,promotionType:3, priceReach:100, priceDown: 8}
                //             ]
                //         }
                //     },
                //     680:{
                //         34958: {
                //             skuMsg: "商品已上架,,2016新年大促销,新年满减大促销",
                //             skuPrice: 10,
                //             skuStatus: 2,
                //             promotions: [
                //                 {promotionName:'2016新年大促销',promotionId:123,promotionType:1, priceDown:1.2},
                //                 {promotionName:'新年满减大促销',promotionId:124,promotionType:4, priceReach:100, priceDown: 8}
                //             ]
                //         },
                //         34961: {
                //             skuMsg: "商品已上架,,2016新年大促销,新年满减大促销",
                //             skuPrice: 10,
                //             skuStatus: 2,
                //             promotions: [
                //                 {promotionName:'2016新年大促销',promotionId:123,promotionType:1, priceDown:1.3, limitNum:2},
                //                 {promotionName:'新年满减大促销',promotionId:124,promotionType:4, priceReach:100, priceDown: 8}
                //             ]
                //         }
                //     },
                //     445:{
                //         27147: {
                //             skuMsg: "商品已上架,,2016新年大促销,新年满减大促销",
                //             skuPrice: 15,
                //             skuStatus: 2,
                //             promotions: [
                //                 {promotionName:'2016新年大促销',promotionId:123,promotionType:1, priceDown:1.2},
                //                 {promotionName:'新年满减大促销',promotionId:124,promotionType:5, priceReach:100, giftList:[
                //                     {id:4445,name:'笔记本赠品'}
                //                 ]}
                //             ]
                //         }
                //     }
                // };
                // validInfo = {
                //     "0": {
                //         "10222": {
                //             "skuStatus": 2,
                //             "skuMsg": "商品已上架,,新年酒饮大促",
                //             "skuPrice": 5.9,
                //             "promotions": [{
                //                 "promotionType": 1,
                //                 "priceDown": 1.2,
                //                 "limitNum": -1,
                //                 "isLogin": false,
                //                 "tipLogin": '登录后享受此优惠',
                //                 "promotionId": 83,
                //                 "promotionName": "新年酒饮大促"
                //             }]
                //         }
                //     }
                // }
                GOODS_PROMOTION_RULE = validInfo;
                // console.log('格式化之后的数据验证：', JSON.stringify(validInfo));
                if (Object.keys(GOODS_PROMOTION_RULE).length) {
                    _updateItems();
                }
            }
        };

        _init();

        return api;
    });
