/**
 * Created by cwt on 2015/9/15.
 */
/**
 * 促销规则
 * @param ruleJson  促销信息 {"promotionName":"八月促销","promotionType":"1","priceReach":"100","priceDown":"12"}
 * @param skuPrice
 * @constructor
 */
var PromotionRule = function(ruleJson) {

    /**
     * 促销活动名称
     */
    this.promotionName = ruleJson.promotionName || '';
    /**
     * 促销规则 1:直降,2:折扣,3:单满减,4:每满减,5:单满赠,6:每满赠
     */
    this.rule = parseInt(ruleJson.promotionType);
    /**
     * 满多少
     */
    this.price_reach = ruleJson.priceReach ? ruleJson.priceReach : 0;
    /**
     * 减多少 or 降多少
     */
    this.price_down = ruleJson.priceDown ? parseFloat(ruleJson.priceDown).toFixed(1) : 0;
    /**
     * 折扣
     */
    this.discount = ruleJson.discount ? ruleJson.discount : 10;

    /**
     * 限购几个
     */
    this.limitNum = ruleJson.limitNum;

    /**
     * 是否登录
     */
    this.isLogin = ruleJson.isLogin;

    /**
     * 登录提示
     */
    this.tipLogin = ruleJson.tipLogin || '';

    /**
     * 单品满赠
     */
    this.giftList = ruleJson.giftList || [];

    var promotionMessage = {
        1: "直降" + parseFloat(this.price_down).toFixed(1) + "元",
        2: this.discount + "折优惠",
        3: "满" + this.price_reach.toFixed(1) + "元，减" + parseFloat(this.price_down).toFixed(1) + "元",
        4: "合计满" + this.price_reach.toFixed(1) + "元，减" + parseFloat(this.price_down).toFixed(1) + "元",
        5: "合计满" + this.price_reach.toFixed(1) + "元，有赠品",
        6: "满" + this.price_reach.toFixed(1) + "元，赠",
        7: "每满" + this.price_reach.toFixed(1) + '元，减' + parseFloat(this.price_down).toFixed(1) + "元",
        8: "每满" + this.price_reach.toFixed(1) + "元，有赠品"
    };
    this.promotionMessage = promotionMessage[this.rule];
};
/**
 * 获取促销提示信息
 * @returns {string}
 */
PromotionRule.prototype.toPromotionMessage = function() {
    if(this.rule == 1 || this.rule == 2){
        var limitTip = '';
        if(this.limitNum > -1 && this.isLogin){
            limitTip = '(限'+ this.limitNum +'件)';
        }
        if(this.limitNum > -1 && !this.isLogin){
            limitTip = this.tipLogin;
        }
        return this.promotionName + ' ' + this.promotionMessage + limitTip;
    }
    if (this.rule == 6) {
        var gift = [];
        for (var i = 0; i < this.giftList.length; i++) {
            var name = this.giftList[i]['name'] || '';
            if (name.length > 5) {
                name = name.slice(0, 4) + '...';
            }
            gift.push(name);
        }
        return this.promotionMessage + " (" + gift.join('+') + ")";
    }
    return this.promotionName + " " + this.promotionMessage;

};
/**
 * 根据促销规则获取应该减的金额
 * @param price 商品单价
 * @param num 商品数量
 * @returns {string}
 */
PromotionRule.prototype.getPromotionPrice = function(price, num) {
    num = num ? num : 1;
    switch (this.rule) {
        case 1:
            var n;
            if(this.limitNum >= 0){
                if(!this.isLogin){
                    n = 0;
                }else{
                    n = Math.min(num, this.limitNum);
                }
            }else{
                n = num;
            }
            return accMul(this.price_down, n, 1);
            break;
        case 2:
            var n;
            if(this.limitNum >= 0){
                if(!this.isLogin){
                    n = 0;
                }else{
                    n = Math.min(num, this.limitNum);
                }
            }else{
                n = num;
            }
            return accDiv(accMul(accMul(price, n, 1), accSub(10, this.discount, 1), 1), 10, 1);
            break;
        case 3:
            if (price >= this.price_reach) {
                return this.price_down;
            }
            return 0;
            break;
        default:
            return null;
            break;
    }
};
