//注意，所有接口方法需要执行callback()方法，即使返回空数组[]空对象{}，因为要隐藏页面中的Loading弹窗
app.service('goodsService', ['$mqDao', function($mqDao) {
    this.queueName = "app_goods_service";

    /**
     * 获取首页栏目 & 获取首页商品
     */
    this.homeColumnByCommunityId = function(callback, communityId){
        var params = {
            communityId: parseInt(communityId) || 0
        };

        $mqDao(this.queueName, homeColumnMap[appEnvironment], params, function(msg) {
            var goodsMap = [];
            var column = {};
            if(msg && msg.homeColumn && msg.homeColumnGoods){
                column = msg.homeColumn;
                angular.forEach(msg.homeColumnGoods, function(goods, i) {
                    var goodsType = goods.homeColumnGoodsType || {};
                    var goodsInfo = goods.homeColumnGoodsGoodsSpuInfo || {};

                    var hasGoodsType = arrayGetItemByKey(goodsMap, 'homeColumnTypeId', goodsType.homeColumnTypeId);

                    if(!hasGoodsType){
                        hasGoodsType = {};
                        hasGoodsType.homeColumnTypeId = goodsType.homeColumnTypeId;
                        hasGoodsType.homeColumnGoodsType = goodsType;
                        hasGoodsType.goodList = [];
                        goodsMap.push(hasGoodsType);
                    }

                    var recommentStr = goods.goodsRecomment || goodsInfo.goodsSpuDescribe;
                    var _goods = {};
                    _goods.goodsSpuId = goodsInfo.goodsSpuId;
                    _goods.goodsImg = parseImgUrlNew(goodsInfo.goodsSpuImgs, 'big');
                    _goods.goodsNote = (goodsInfo.goodsSpuName + '：' + recommentStr).substr(0, 20) + '...';
                    _goods.goodsTPrice = parseFloat(goodsInfo.goodsSpuPrice.promotionalPrice);
                    _goods.goodsPrice = parseFloat(goodsInfo.goodsSpuPrice.originalPrice);
                    _goods.goodsPromotionStatus = Object.keys(goodsInfo.goodsSpuPromotionInfo).length > 0;
                    _goods.goodsPromotionTypeKey = promotionTypeToKeyNew(goodsInfo.goodsSpuPromotionInfo || {});
                    _goods.goodsSpuOnBusiness = goodsInfo.goodsSpuOnBusiness == 1; //是否营业 0-未营业 1-营业
                    _goods.cartInfo = goodsInfo;

                    hasGoodsType.goodList.push(_goods);
                });
            }
            callback({
                homeColumn: column,
                homeGoods: goodsMap
            });
        });
    };

    /**
     * 获取按与用户距离排序的店铺(供应商)列表
     * @param callback
     * @param position 用户位置 {lat: 123, lon:234}
     * @param categoryId 品类Id（顶级Id）。
     * @param subCategoryId 品类Id（二级Id）。
     * @param orderBy 排序规则，1-默认  2-营业  3-距离  4-热销，5-好评 默认按shop_brand_sort字段正序
     * @param page 分页对象
     * @return 按由近及远排序的店铺列表。供应商下多店铺时取最近距离。
     */
    this.getShopBrandListForUser = function(callback, position, categoryId, orderBy, page) {
        var params = {
            userLatitude: position.lat,
            userLongitude: position.lon,
            categoryId: categoryId,
            orderBy: orderBy,
            page: page.getCurrentPage()
        };
        $mqDao(this.queueName, 'getShopBrandListForUser', params, function(msg) {
            var data = [];
            if(msg && msg.length){
                data = msg;
            }
            callback(data);
            page.updateCurrentPage();
        });
    };

    /**
     * 获取店铺列表
     * @param callback 回调函数
     * @param page 当前页数
     */
    this.getShopListBySortId = function(callback, page) {
        var sortId = window.localStorage.getItem('shopList');
        var params = {
            sortId: sortId, //分类Id
            startPos: page.getCurrentPage(), //起始页
            sort: 1 //排序
        };
        $mqDao(this.queueName, 'getShopListBySortId', params, function(msg) {
            var data = [];
            if (msg && msg.length) {
                angular.forEach(msg, function(shop, index) {
                    var _shop = {};
                    var _imgUrl = parseImgUrl(shop.shop_brand_img_urls, 'medium');
                    _shop.shopName = shop.shop_brand_name;
                    _shop.shopImgUrl = _imgUrl;
                    _shop.shopDescribe = shop.shop_brand_describe;
                    _shop.commentCount = shop.commentCount;
                    _shop.hasNew = true;
                    _shop.starNum = shop.starNum;
                    data.push(_shop);
                });
            }
            callback(data);
            page.updateCurrentPage();
        });
    };

    /**
     * 获取自营商品列表,查询商品列表
     * @param categoryId 品类id（顶级Id）
     * @param subCategoryId 品类Id（二级Id）。
     * @param orderBy 排序
     * @param page 分页信息
     * @return
     */
    this.queryGoodsSpuListByPage = function(callback, categoryFirstLevelId, categorySencondLevelId, categoryThreeLevelId, orderBy, page) {
        var params = {
            pageInfo: {
                pageNum: page.getCurrentPage()
            },
            goodsSpu: {
                goodsSpuCategory: {
                    categoryFirstId: parseInt(categoryFirstLevelId),
                    categoryPId: categorySencondLevelId == null ? categorySencondLevelId : parseInt(categorySencondLevelId),
                    categoryId: categoryThreeLevelId == null ? categoryThreeLevelId : parseInt(categoryThreeLevelId)
                },
                sort: orderBy.toString()
            }
        };
        $mqDao(this.queueName, 'queryGoodsSpuListByPage', params, function(msg) {
            var data = [];
            if (msg && msg.length) {
                angular.forEach(msg, function(goods, i) {

                    var _goods = {};
                    _goods.goodsSpuShopBrandName = goods.goodsSpuShopBrandName;
                    _goods.goodsSpuId = goods.goodsSpuId;
                    _goods.goodsSpuName = goods.goodsSpuName;
                    _goods.imgUrl = parseImgUrlNew(goods.goodsSpuImgs, 'medium');
                    _goods.goodsSort = goods.goodsSpuType == 1; //商品是否荷粉自营0-自营 1-非自营，默认0
                    _goods.shopOff = goods.goodsSpuOnBusiness == 0; //商品是否营业0-未营业 1-营业，默认1
                    _goods.starNum = goods.goodsSpuCommentInfo.goodsStarNum;
                    _goods.promotionTypeKey = promotionTypeToKeyNew(goods.goodsSpuPromotionInfo || {});
                    _goods.TPrice = parseFloat(goods.goodsSpuPrice.promotionalPrice);
                    _goods.Price = parseFloat(goods.goodsSpuPrice.originalPrice);
                    _goods.commentNum = goods.goodsSpuCommentInfo.goodsCommentNum;
                    _goods.cartInfo = goods;
                    data.push(_goods);
                });
            }
            callback(data);
            page.updateCurrentPage();
        })
    };

    /**
     * 获取自营商品列表,查询商品列表
     * @param categoryId 品类id（顶级Id）
     * @param subCategoryId 品类Id（二级Id）。
     * @param orderBy 排序
     * @param page 分页信息
     * @param lat
     * @param lon
     * @return
     */
    this.queryGoodsSpuListByPageWithDistanceCommunityId = function(callback, categoryFirstLevelId, categorySencondLevelId, categoryThreeLevelId, orderBy, page, communityId){
        var params = {
            pageInfo: {
                pageNum: page.getCurrentPage()
            },
            goodsSpu: {
                goodsSpuCategory: {
                    categoryFirstId: parseInt(categoryFirstLevelId),
                    categoryPId: categorySencondLevelId == null ? categorySencondLevelId : parseInt(categorySencondLevelId),
                    categoryId: categoryThreeLevelId == null ? categoryThreeLevelId : parseInt(categoryThreeLevelId)
                },
                sort: orderBy.toString()
            },
            communityId: parseInt(communityId) || 0
        };

        $mqDao(this.queueName, 'queryGoodsSpuListByPageWithDistanceCommunityId', params, function(msg) {
            var data = [];
            if (msg && msg.length) {
                angular.forEach(msg, function(goods, i) {
                    var _goods = {};
                    _goods.goodsSpuShopBrandName = goods.goodsSpuShopBrandName;
                    _goods.goodsSpuId = goods.goodsSpuId;
                    _goods.goodsSpuName = goods.goodsSpuName;
                    _goods.imgUrl = parseImgUrlNew(goods.goodsSpuImgs, 'medium');
                    _goods.goodsSort = goods.goodsSpuType == 1; //商品是否荷粉自营0-自营 1-非自营，默认0
                    _goods.hideShop = goods.hideShop; // 是否隐藏进店按钮
                    _goods.shopOff = goods.goodsSpuOnBusiness == 0; //商品是否营业0-未营业 1-营业，默认1
                    _goods.starNum = goods.goodsSpuCommentInfo.goodsStarNum;
                    _goods.promotionTypeKey = promotionTypeToKeyNew(goods.goodsSpuPromotionInfo || {});
                    _goods.TPrice = parseFloat(goods.goodsSpuPrice.promotionalPrice);
                    _goods.Price = parseFloat(goods.goodsSpuPrice.originalPrice);
                    _goods.commentNum = goods.goodsSpuCommentInfo.goodsCommentNum;
                    _goods.cartInfo = goods;
                    data.push(_goods);
                });
            }
            callback(data);
            page.updateCurrentPage();
        });
    };

    /**
     * 获取店铺商品列表
     * @param callback 回调函数
     */
    this.queryShopGoodsList = function(callback, shopBrandName, promotion) {

        var params = {
            goodsSpu: {
                goodsSpuShopBrandName: shopBrandName, //店铺名
                goodsSpuPromotionInfo: promotion
            },
            start: 1, //加载页数
            length: 1000, //每页数量
            sort: 2 //排序
        };
        $mqDao(this.queueName, 'queryShopGoodsList', params, function(msg) {
            var data = [];
            if (msg.resultTO && msg.resultTO.length) {
                var sortNameOld = "";
                var _sort = {};
                _sort.goodList = [];
                angular.forEach(msg.resultTO, function(goods, i) {
                    if (!sortNameOld) {
                        sortNameOld = goods.goodsSpuCategory.shopCustomCategoryName;
                    }
                    if (goods.goodsSpuCategory.shopCustomCategoryName != sortNameOld) {
                        data.push(_sort);
                        _sort = {};
                        _sort.goodList = [];
                        sortNameOld = goods.goodsSpuCategory.shopCustomCategoryName;
                    }
                    var _goods = {};
                    _goods.goodsSpuId = goods.goodsSpuId;
                    _goods.goodsSpuName = goods.goodsSpuName;
                    _goods.goodsImg = parseImgUrlNew(goods.goodsSpuImgs, 'small');
                    _goods.goodsTPrice = parseFloat(goods.goodsSpuPrice.promotionalPrice);
                    _goods.goodsPrice = parseFloat(goods.goodsSpuPrice.originalPrice);
                    _goods.goodsPromotionTypeKey = promotionTypeToKeyNew(goods.goodsSpuPromotionInfo || {});
                    _goods.goodsSpuCommentInfo = goods.goodsSpuCommentInfo;
                    _goods.goodsSpuOnBusiness = goods.goodsSpuOnBusiness == 1; //商品是否营业0-未营业1-营业，默认1
                    _goods.cartInfo = goods;

                    _sort.name = goods.goodsSpuCategory.shopCustomCategoryName;
                    _sort.goodList.push(_goods);

                    if (msg.resultTO.length == i + 1) {
                        data.push(_sort);
                    }
                });
            }
            callback(data);
        });
    };

    /**
     * 新获取店铺商品列表
     * @param callback 回调函数
     */
    this.queryShopGoodsListByCommunityId = function(callback, shopBrandName, communityId) {

        var params = {
            	shopBrandName: shopBrandName, //店铺名
            	communityId: communityId
        };
        $mqDao(this.queueName, 'queryShopGoodsListByCommunityId', params, function(msg) {
            var data = {
                'shop' : msg.shopBrandInfo,
                'goods' : []
            };
            if (msg.resultTO && msg.resultTO.length) {
                var sortNameOld = "";
                var _sort = {};
                _sort.goodList = [];
                angular.forEach(msg.resultTO, function(goods, i) {
                    if (!sortNameOld) {
                        sortNameOld = goods.goodsSpuCategory.shopCustomCategoryName;
                    }
                    if (goods.goodsSpuCategory.shopCustomCategoryName != sortNameOld) {
                        data.goods.push(_sort);
                        _sort = {};
                        _sort.goodList = [];
                        sortNameOld = goods.goodsSpuCategory.shopCustomCategoryName;
                    }
                    var _goods = {};
                    _goods.goodsSpuId = goods.goodsSpuId;
                    _goods.goodsSpuName = goods.goodsSpuName;
                    _goods.goodsImg = parseImgUrlNew(goods.goodsSpuImgs, 'small');
                    _goods.goodsTPrice = parseFloat(goods.goodsSpuPrice.promotionalPrice);
                    _goods.goodsPrice = parseFloat(goods.goodsSpuPrice.originalPrice);
                    _goods.goodsPromotionTypeKey = promotionTypeToKeyNew(goods.goodsSpuPromotionInfo || {});
                    _goods.goodsSpuCommentInfo = goods.goodsSpuCommentInfo;
                    _goods.goodsSpuOnBusiness = goods.goodsSpuOnBusiness == 1; //商品是否营业0-未营业1-营业，默认1
                    _goods.cartInfo = goods;

                    _sort.name = goods.goodsSpuCategory.shopCustomCategoryName;
                    _sort.goodList.push(_goods);

                    if (msg.resultTO.length == i + 1) {
                        data.goods.push(_sort);
                    }
                });
            }
            callback(data);
        });
    };

    /**
     * 获取商品详情
     * @param callback
     * @param id 商品(spu)Id
     * @param resource 来源，此时有扫码来源 其他情况为空字符
     * @param phone 用户手机号，用于查询此手机号买过几次扫码商品
     */
    this.goodsSpuDetails = function(callback, id, resource, phone) {
        var params = {
            goodsSpu: {
                goodsSpuId: id
            },
            resource: resource||'',
            userMobile: phone
        };
        $mqDao(this.queueName, 'goodsSpuDetails', params, function(msg) {
            // var data = {};
            if(msg && Object.keys(msg.resultTO||{}).length){
                msg.resultTO.goodsSpuPrice.originalPrice = parseFloat(msg.resultTO.goodsSpuPrice.originalPrice);
                msg.resultTO.goodsSpuPrice.promotionalPrice = parseFloat(msg.resultTO.goodsSpuPrice.promotionalPrice);
                msg.resultTO.goodsSpuPromotionKeys = promotionTypeToKeyNew(msg.resultTO.goodsSpuPromotionInfo);
                msg.resultTO.goodsSpuPromotionKeyAndText = promotionTypeToKeyAndText(msg.resultTO.goodsSpuPromotionInfo);
                // data = msg;
            }
            callback(msg);
        });
    };

    /**
     * 获取商品图文详情
     * @param callback
     * @param id 商品(spu)Id
     */
    this.queryGoodsSpuDescribeHtml = function(callback, id) {
        var params = {
            goodsSpuId: id
        };
        $mqDao(this.queueName, 'queryGoodsSpuDescribeHtml', params, function(msg) {
            var data = {};
            if(msg && Object.keys(msg).length){
                data = msg;
            }
            callback(data);
        });
    };

    /**
     * 获取分类数据
     * @param callback 回调函数
     */
    this.queryIndexCategory = function(callback) {
        var params = {};
        $mqDao(this.queueName, queryIndexCategoryMap[appEnvironment], params, function(msg) {
            callback(msg.resultTO);
        });
    };

    /**
     * 获取所选商品列表
     * @param callback
     * @param list 所选的商品ID集合
     */
    this.queryGoodsSpuListByCustom = function(callback, list, page){

        var params = {
            goodsSpuIdList: list,
            pageNum: page.getCurrentPage()
        };

        $mqDao(this.queueName, 'queryGoodsSpuListByGoodsSpuIdList', params, function(msg){
            var data = [];
            if (msg && msg.length) {
                angular.forEach(msg, function(goods, i) {
                    var _goods = {};
                    _goods.goodsSpuShopBrandName = goods.goodsSpuShopBrandName;
                    _goods.goodsSpuId = goods.goodsSpuId;
                    _goods.goodsSpuName = goods.goodsSpuName;
                    _goods.imgUrl = parseImgUrlNew(goods.goodsSpuImgs, 'medium');
                    _goods.goodsSort = goods.goodsSpuType == 1; //商品是否荷粉自营0-自营 1-非自营，默认0
                    _goods.hideShop = goods.hideShop;
                    _goods.shopOff = goods.goodsSpuOnBusiness == 0; //商品是否营业0-未营业 1-营业，默认1
                    _goods.starNum = goods.goodsSpuCommentInfo.goodsStarNum;
                    _goods.promotionTypeKey = promotionTypeToKeyNew(goods.goodsSpuPromotionInfo || {});
                    _goods.TPrice = parseFloat(goods.goodsSpuPrice.promotionalPrice);
                    _goods.Price = parseFloat(goods.goodsSpuPrice.originalPrice);
                    _goods.commentNum = goods.goodsSpuCommentInfo.goodsCommentNum;
                    _goods.cartInfo = goods;
                    data.push(_goods);
                });
            }
            callback(data);
            page.updateCurrentPage();
        });
    };

    /**
     * 查询商品列表的品类
     * @param callback
     * @param communityId 定位的小区ID
     * @param categoryFirstId 第一级品类ID
     * @param categoryPId 第二级品类ID
     * @param categoryId 第三级品类ID
     * @return Array 店铺列表
     */
    this.queryGoodsSpuCategoryListByCommunity = function(callback, communityId, categoryFirstId, categoryPId, categoryId){
        var params = {
            goodsSpu: {
                goodsSpuCategory: {
                    categoryFirstId: parseInt(categoryFirstId),
                    categoryPId: categoryPId == null ? categoryPId : parseInt(categoryPId),
                    categoryId: categoryId == null ? categoryId : parseInt(categoryId)
                }
            },
            communityId: parseInt(communityId) || 0
        };
        $mqDao(this.queueName, 'queryGoodsSpuCategoryListByCommunity', params, function(msg){
            var result = [];
            if(msg && msg.length){
                result = parseCategory(msg);
            }
            callback(result);
        });
    };

    /**
     * 广告跳转
     * @param advertId 广告id
     * @return
     * {"resultMsg":"","resultCode":"success","resultTO":{"params":"('2458')","methodName":"toProductDetails"}}
     */

    this.advertJump = function(callback, id){
        var params = {
            advertId: parseInt(id) || 0
        };
        $mqDao(this.queueName, 'advertJump', params, function(msg){
            // console.log('service:',msg);
            var result = {};
            if(msg && msg.resultCode){
                result = msg;
            }
            callback(result);
        });
    };

    /**
     * 查询特惠商品列表
     * @param {Function} callback 回调函数
     * @param {String} phone 用户手机号，未登录时为空
     * @param {Int} communityId 用户定位地址
     * @return
     */
    // @IsMqFunction(paramNames={})
    // public ResultMap queryPreferenceGoodsSpuList();
    this.queryPreferenceGoodsSpuListNoPromotion = function(callback, phone, communityId){
        var params = {
            mobile: phone || '',
            communityId: parseInt(communityId) || 0
        };
        $mqDao(this.queueName, 'queryPreferenceGoodsSpuListNoPromotion', params, function(msg){
            // console.log('service:',msg);


            // msg = {
            //     "resultMsg": "",
            //     "resultCode": "success",
            //     "resultTO": {
            //         "todayPreferenceList": [{
            //             "SERVER_TIME": 1463640832594,
            //             "leftNumAll": 0,
            //             "leftNumOne": 0,
            //             "mobile": "",
            //             "preferenceBeginTime": {
            //                 "date": 18,
            //                 "day": 3,
            //                 "hours": 11,
            //                 "minutes": 6,
            //                 "month": 4,
            //                 "seconds": 23,
            //                 "time": 1463540783000,
            //                 "timezoneOffset": -480,
            //                 "year": 116
            //             },
            //             "preferenceBeginTimeL": 1463540783000,
            //             "preferenceDescribe": "测试描述",
            //             "preferenceEndTime": {
            //                 "date": 26,
            //                 "day": 4,
            //                 "hours": 11,
            //                 "minutes": 6,
            //                 "month": 4,
            //                 "seconds": 23,
            //                 "time": 1464231983000,
            //                 "timezoneOffset": -480,
            //                 "year": 116
            //             },
            //             "preferenceEndTimeL": 1464231983000,
            //             "preferenceGoodsSpu": {
            //             },
            //             "preferenceGoodsSpuId": 5,
            //             "preferenceHefenPrice": 5.3,
            //             "preferenceId": 1,
            //             "preferenceImg": "",
            //             "preferenceLimitNumAll": 10,
            //             "preferenceLimitNumOne": 2,
            //             "preferenceName": "测试1",
            //             "preferenceOriginalPrice": 6.2,
            //             "preferenceStatus": 1,
            //
            //         }],
            //         "tomorrowPreferenceList": []
            //     }
            // }
            // console.log('rmy:',msg);
            var result = {};
            result.today = [];
            result.tomorrow = [];
            if(msg && msg.resultCode == 'success'){
                var dataToday = msg.resultTO.todayPreferenceList || [];
                var dataTomorrow = msg.resultTO.tomorrowPreferenceList || [];

                var localTime = (new Date()).getTime();

                for (var i = 0; i < dataToday.length; i++) {
                    var item = dataToday[i];
                    item.diffTime = item.SERVER_TIME - localTime;
                    item.showDay = 'today';
                }

                for (var i = 0; i < dataTomorrow.length; i++) {
                    var item = dataTomorrow[i];
                    item.diffTime = item.SERVER_TIME - localTime;
                    item.showDay = 'tomorrow';
                }

                result.today = parsePreferenceData(dataToday);
                result.tomorrow = parsePreferenceData(dataTomorrow);

            }
            callback(result);
        });
    };

}]);
