app.service('orderService', ['$mqDao', function($mqDao) {
    this.queueName = "app_order_service";
    /**
     * 注意，所有接口方法需要执行callback()方法，即使返回空数组[]空对象{}，因为要隐藏页面中的Loading弹窗
     */

    /**
	 * queryOrderList查看订单列表（订单列表页）
	 * @param page 当前页数 从1开始
	 * @param length 每页显示数据条数
	 * @param userMobile 用户手机号/账号
	 * @return
	 */
    this.getOrderListByUserMobile = function(callback, orderType, page, length, userMobile) {
        var mobile = userMobile;
        var order = 0;
        // 订单状态 0-未确认1-订单确认，2-采购完成，3-派送中, 4-派送完成（订单完成），5-已评论，7-订单取消，8-采购中，9-用户确认收货
        if (orderType == "current") {
            order = 0;
        } else {
            order = 1;
        }
        var params = {
            complated: order,		//订单状态（0 未完成，1已完成）
            orderMobile: mobile,//下单电话
            page: page
        };
        $mqDao(this.queueName, 'queryOrderList', params, function(msg) {
            callback(msg);
        });
    };

    /**
     * 修改订单状态
     * @param callback  回调函数
     * @param orderInfo     orderInfo{orderId: 订单Id,orderStatus: 订单状态}
     * @return 1 更新成功 0 更新失败
     */
    this.updateOrder = function(callback, orderInfo){
        var params = {
            orderInfo: orderInfo
        };
        $mqDao(this.queueName, 'updateOrder', params, function(msg) {
            callback(msg);
        });
    };


    /**
     * 取消订单
     * @param callback  回调函数
     * @param orderInfo     orderInfo{orderId: 订单Id,orderStatus: 订单状态}
     * @return 1 取消成功 0 取消失败
     */
    this.cancelOrder = function(callback, orderInfo){
        var params = {
            orderInfo: orderInfo
        };
        $mqDao(this.queueName, 'cancelOrder', params, function(msg) {
            callback(msg);
        });
    };

    /**
     * 获取订单信息
     * @param callback  回调函数
     * @param orderInfo     orderInfo{orderId: 订单Id}
     * @return 1 取消成功 0 取消失败
     */
    this.queryOrder = function(callback, orderInfo){
        var params = {
            orderInfo: orderInfo
        };
        $mqDao(this.queueName, 'queryOrder', params, function(msg) {

            var firstOrderPriceDown = 0;
            var firstOrder = false;
            if( msg.orderActivityInfo ) {
            } else {
                firstOrderPriceDown = 0;
                firstOrder = false;
            }
            var orderSendTime = msg.orderStatusTime.PAISONGZHONG||0;

            var vouchersPrice = 0;
            var vouchers = msg.orderCost.vouchers;
            for( var i=0;i<vouchers.length;i++) {
            	vouchersPrice += parseFloat(vouchers[i].couponPrice);
            }
            /****当存在满赠商品时  将其插入到singleGoods中  赠品加到giftList中*****/
            var orderInfoShopGoods = msg.orderGoodsInfo;
            for( var key in orderInfoShopGoods ) {
            	if( orderInfoShopGoods[key]["groupGoods"] ) {
            		orderInfoShopGoods[key]["giftList"] = [];
            		for( var pro in orderInfoShopGoods[key].groupGoods ) {
            			if( orderInfoShopGoods[key].groupGoods[pro].goodses ) {
            				orderInfoShopGoods[key].singleGoods = orderInfoShopGoods[key].singleGoods.concat(orderInfoShopGoods[key].groupGoods[pro].goodses);
            				// console.log(JSON.stringify(orderInfoShopGoods[key].singleGoods));
            			}
            			if( orderInfoShopGoods[key].groupGoods[pro].giftList ) {
            				orderInfoShopGoods[key]["giftList"] = orderInfoShopGoods[key]["giftList"].concat(orderInfoShopGoods[key].groupGoods[pro].giftList);
            				// console.log(JSON.stringify(orderInfoShopGoods[key].groupGoods[pro].giftList));
            				// console.log(JSON.stringify(orderInfoShopGoods[key]["giftList"]));
            			}
            		}
            	}
            }

            var orderInfoAll = {
                orderInfoSend:{
                    orderNumApp : msg.orderNumApp,
                    orderNum : msg.orderNum,
                    currentTime : msg.currentTime,
                    orderSendTime : orderSendTime
                },
                orderInfoAddress:{
                    contactPerson : msg.orderAddress.contactPerson,
                    contactPhone : msg.orderAddress.contactPhone,
                    communityName : msg.orderAddress.communityName,
                    addressContent : msg.orderAddress.addressContent,
                    addressId : msg.orderAddress.addressId
                },
                orderInfoPrice:{
                    amountPayable : msg.orderCost.orderprice.amountPayable,    //实际支付金额
                    goodsTotalPrice : msg.orderCost.orderprice.goodsTotalPrice,   //商品金额
                    freight : msg.orderCost.freight,                //运费
                    vouchersPrice : vouchersPrice.toFixed(2),          //优惠券金额
                    firstOrderPriceDown : firstOrderPriceDown,    //首单减免金额
                    firstOrder : firstOrder          //首单减免判断
                },
                payStatus : msg.orderPayInfo.payStatus,
                payMethod : msg.orderPayInfo.payMethod,
                orderInfoShopGoods : msg.orderGoodsInfo,
                orderStatus : msg.orderStatus
            };
            callback(orderInfoAll);
        });
    };

    /**
     * 根据子订单信息查询子订单
     * @param bossOrderNum
     * @return
     */
    // @IsMqFunction(paramNames = {"bossOrderNum"})
    // public Map<String, Object> bossOrderDetails(String bossOrderNum);
    this.bossOrderDetails = function(callback, bossOrderNum){
        var params = {
            bossOrderNum: bossOrderNum||''
        };
        $mqDao(this.queueName, 'bossOrderDetails', params, function(msg) {

            var firstOrderPriceDown = 0;
            var firstOrder = false;
            if( msg.orderActivityInfo ) {
            } else {
                firstOrderPriceDown = 0;
                firstOrder = false;
            }
            var orderSendTime = msg.orderStatusTime.PAISONGZHONG||0;

            var vouchersPrice = 0;
            var vouchers = msg.orderCost.vouchers;
            for( var i=0;i<vouchers.length;i++) {
                vouchersPrice += parseFloat(vouchers[i].couponPrice);
            }
            /****当存在满赠商品时  将其插入到singleGoods中  赠品加到giftList中*****/
            var orderInfoShopGoods = msg.orderGoodsInfo;
            for( var key in orderInfoShopGoods ) {
                if( orderInfoShopGoods[key]["groupGoods"] ) {
                    orderInfoShopGoods[key]["giftList"] = [];
                    for( var pro in orderInfoShopGoods[key].groupGoods ) {
                        if( orderInfoShopGoods[key].groupGoods[pro].goodses ) {
                            orderInfoShopGoods[key].singleGoods = orderInfoShopGoods[key].singleGoods.concat(orderInfoShopGoods[key].groupGoods[pro].goodses);
                            // console.log(JSON.stringify(orderInfoShopGoods[key].singleGoods));
                        }
                        if( orderInfoShopGoods[key].groupGoods[pro].giftList ) {
                            orderInfoShopGoods[key]["giftList"] = orderInfoShopGoods[key]["giftList"].concat(orderInfoShopGoods[key].groupGoods[pro].giftList);
                            // console.log(JSON.stringify(orderInfoShopGoods[key].groupGoods[pro].giftList));
                            // console.log(JSON.stringify(orderInfoShopGoods[key]["giftList"]));
                        }
                    }
                }
            }

            var orderInfoAll = {
                orderInfoSend:{
                    orderNumApp : msg.orderNumApp,
                    orderNum : msg.orderNum,
                    currentTime : msg.currentTime,
                    orderSendTime : orderSendTime
                },
                orderInfoAddress:{
                    contactPerson : msg.orderAddress.contactPerson,
                    contactPhone : msg.orderAddress.contactPhone,
                    communityName : msg.orderAddress.communityName,
                    addressContent : msg.orderAddress.addressContent,
                    addressId : msg.orderAddress.addressId
                },
                orderInfoPrice:{
                    amountPayable : msg.orderCost.orderprice.amountPayable,    //实际支付金额
                    goodsTotalPrice : msg.orderCost.orderprice.goodsTotalPrice,   //商品金额
                    freight : msg.orderCost.freight,                //运费
                    vouchersPrice : vouchersPrice.toFixed(2),          //优惠券金额
                    firstOrderPriceDown : firstOrderPriceDown,    //首单减免金额
                    firstOrder : firstOrder          //首单减免判断
                },
                payStatus : msg.orderPayInfo.payStatus,
                payMethod : msg.orderPayInfo.payMethod,
                orderInfoShopGoods : msg.orderGoodsInfo,
                orderStatus : msg.orderStatus
            };
            orderInfoAll['shopInfo'] = msg.shopInfo||{};
            orderInfoAll['orderInfoPrice']['promotionPriceDown'] = msg.orderCost.orderprice.promotionPriceDown||0;
            orderInfoAll['orderInfoPrice']['couponPriceDown'] = msg.orderCost.orderprice.couponPriceDown||0;
            orderInfoAll['bossOrderStatus'] = msg.bossOrderStatus;
            orderInfoAll['bossOrderShopOrderNum'] = msg.bossOrderShopOrderNum;
            orderInfoAll['orderPayInfo'] = msg.orderPayInfo || {};
            orderInfoAll['orderPaymentType'] = msg.orderPaymentType;
            orderInfoAll['msg'] = msg || {};

            callback(orderInfoAll);
        });
    };

    /**
     * 查看购物车的商品信息
     * @param callback
     * @param orderInfo
     */
    this.againOrderGoodsInfo = function(callback, orderInfo){
        var params = {
            orderInfo: orderInfo
        };
        $mqDao(this.queueName, 'orderGoodsInfo', params, function(msg) {
            callback(msg);
        });
    };

    /**
     * 校验购物车商品信息，sku上下架状态、价格是否修改、促销信息是否修改
     * @param callback 回调函数
     * @param info sku列表信息
     * @param phone 用户手机号
     */
    this.checkShoppingCart = function(callback, info, phone){
        var params = {
            shoppingCartInfo: info,
            orderMobile: phone || ''
        };
        /*
        var msg = {
            "resultFlush": {
                "1050": [{
                    "skuPromotion": [{
                        "promotionId": 68,
                        "promotionTerm": {
                            "limitNum": 5,
                            "promotionType": 8,
                            "priceReach": 10,
                            "giftList": [{name:'赠品111'},{name:'赠品222'}]
                        },
                        "promotionName": "分别直降111"
                    }],
                    "skuPrice": "2",
                    "skumsg": "商品已上架,null",
                    "skustatus": 2,
                    "skuId": 37773
                },
                {
                    "skuPromotion": [{
                        "promotionId": 68,
                        "promotionTerm": {
                            "promotionType": 8,
                            "priceReach": 10,
                            "giftList": [{name:'赠品111'},{name:'赠品222'}]
                        },
                        "promotionName": "分别直降111"
                    }],
                    "skuPrice": "2",
                    "skumsg": "商品已上架,null",
                    "skustatus": 2,
                    "skuId": 37770
                }],
                "0": [{
                    "skuPromotion": [],
                    "skuPrice": 79.8,
                    "skumsg": ",11月粮油大促",
                    "skustatus": 4,
                    "skuId": 14381
                }]
            },
            "resultCode": "success"
        };
        */
        $mqDao(this.queueName, 'checkShoppingCart', params, function(msg) {

            var data2 = {};
            data2.appServerStatus = msg.appServerStatus||'';
            data2.resultCode = msg.resultCode;
            data2.resultMsg = msg.resultMsg||'';
            data2.resultFlush = {};
            for(shopId in msg.resultFlush){
                data2['resultFlush'][shopId] = {};
                var _skuList = msg.resultFlush[shopId];
                for(var i=0; i<_skuList.length; i++){
                    var sku = _skuList[i];
                    var promotions = [];
                    if(sku['skuPromotion']){
                        for(var j=0; j<sku['skuPromotion'].length; j++){
                            var promotion = sku['skuPromotion'][j];
                            var _pro = promotion['promotionTerm'] ||{};
                            _pro['promotionId'] = promotion['promotionId'];
                            _pro['promotionName'] = promotion['promotionName'];
                            promotions.push(_pro);
                        }
                    }
                    data2['resultFlush'][shopId][sku.skuId] = {};
                    data2['resultFlush'][shopId][sku.skuId]['skuStatus'] = sku['skustatus']||"";
                    data2['resultFlush'][shopId][sku.skuId]['skuMsg'] = sku['skumsg']||"";
                    data2['resultFlush'][shopId][sku.skuId]['preferenceId'] = sku['preferenceId'];
                    data2['resultFlush'][shopId][sku.skuId]['leftNumOne'] = sku['leftNumOne'];
                    data2['resultFlush'][shopId][sku.skuId]['skuPrice'] = sku['skuPrice']||data2['resultFlush'][shopId][sku.skuId]['skuPrice'];
                    data2['resultFlush'][shopId][sku.skuId]['promotions'] = promotions;
                }
            }

            callback(data2);
        });
    };

    /**
     * 校验购物车商品信息，sku上下架状态、价格是否修改、促销信息是否修改
     * @param callback 回调函数
     * @param info sku列表信息
     * @param phone 用户手机号
     */
    this.checkShoppingCartNew = function(callback, info, phone, communityId){
        var params = {
            shoppingCartInfo: info,
            orderMobile: phone || '',
            communityId: parseInt(communityId) || 0
        };
        /*
        var msg = {
            "resultFlush": {
                "1050": [{
                    "skuPromotion": [{
                        "promotionId": 68,
                        "promotionTerm": {
                            "limitNum": 5,
                            "promotionType": 8,
                            "priceReach": 10,
                            "giftList": [{name:'赠品111'},{name:'赠品222'}]
                        },
                        "promotionName": "分别直降111"
                    }],
                    "skuPrice": "2",
                    "skumsg": "商品已上架,null",
                    "skustatus": 2,
                    "skuId": 37773
                },
                {
                    "skuPromotion": [{
                        "promotionId": 68,
                        "promotionTerm": {
                            "promotionType": 8,
                            "priceReach": 10,
                            "giftList": [{name:'赠品111'},{name:'赠品222'}]
                        },
                        "promotionName": "分别直降111"
                    }],
                    "skuPrice": "2",
                    "skumsg": "商品已上架,null",
                    "skustatus": 2,
                    "skuId": 37770
                }],
                "0": [{
                    "skuPromotion": [],
                    "skuPrice": 79.8,
                    "skumsg": ",11月粮油大促",
                    "skustatus": 4,
                    "skuId": 14381
                }]
            },
            "resultCode": "success"
        };
        */
        $mqDao(this.queueName, 'checkShoppingCartNew', params, function(msg) {
            var data2 = {};
            data2.appServerStatus = msg.appServerStatus||'';
            data2.resultCode = msg.resultCode;
            data2.resultMsg = msg.resultMsg||'';
            data2.resultFlush = {};
            for(shopId in msg.resultFlush){
                data2['resultFlush'][shopId] = {};
                var _skuList = msg.resultFlush[shopId];
                for(var i=0; i<_skuList.length; i++){
                    var sku = _skuList[i];
                    var promotions = [];
                    if(sku['skuPromotion']){
                        for(var j=0; j<sku['skuPromotion'].length; j++){
                            var promotion = sku['skuPromotion'][j];
                            var promotionTerm = promotion['promotionTerm'] || {};
                            var promotionTmp = hashExtend({}, promotion, promotionTerm);
                            promotions.push(promotionTmp);
                        }
                    }
                    data2['resultFlush'][shopId][sku.skuId] = {};
                    data2['resultFlush'][shopId][sku.skuId]['shopBrandFreight'] = sku['shopBrandFreight'];
                    data2['resultFlush'][shopId][sku.skuId]['shopBrandFreightReduce'] = sku['shopBrandFreightReduce'];
                    data2['resultFlush'][shopId][sku.skuId]['hefenOverTimeNotice'] = sku['hefenOverTimeNotice'];
                    data2['resultFlush'][shopId][sku.skuId]['skuStatus'] = sku['skustatus']||"";
                    data2['resultFlush'][shopId][sku.skuId]['skuMsg'] = sku['skumsg']||"";
                    data2['resultFlush'][shopId][sku.skuId]['preferenceId'] = sku['preferenceId'];
                    data2['resultFlush'][shopId][sku.skuId]['leftNumOne'] = sku['leftNumOne'];
                    data2['resultFlush'][shopId][sku.skuId]['skuPrice'] = sku['skuPrice']||data2['resultFlush'][shopId][sku.skuId]['skuPrice'];
                    data2['resultFlush'][shopId][sku.skuId]['promotions'] = promotions;
                }
            }

            callback(data2);
        });
    };

    /**
     * 校验购物车价格
     * @param callback 回调函数
     * @param info sku列表信息
     * @return
     */
    this.checkShopingCartCost = function(callback, info){
        var params = {
            shoppingCartInfo: info
        };
        $mqDao(this.queueName, 'checkShopingCartCost', params, function(msg){
            callback(msg);
        });
    };

    /**
     * 订单提交页面获取数据
     * @param callback 回调函数
     * @param userMobile 登陆手机号
     * @return
     */
    this.userShopingCartInfo = function(callback, userMobile){
        var params = {
            shoppingCartInfo:{'orderMobile':userMobile}
        };
        $mqDao(this.queueName, 'userShopingCartInfo', params, function(msg){
            callback(msg);
        });
    };

    /**
     * 订单提交
     * @param callback 回调函数
     * @param orderInfo 订单数据
     * @return
     */
    this.addOrder = function(callback, orderInfo){
        var params = {
            orderInfo : orderInfo
        };
        $mqDao(this.queueName, 'addOrder', params, function(msg){
            callback(msg);
        });
    };
    this.addOrderBack = function(callback, orderInfo){
        var params = {
            orderInfo : orderInfo
        };

        $mqDao(this.queueName, addOrderBackMap[appEnvironment], params, function(msg){
            callback(msg);
        });
    };

    /**
     * 查询购物车广播
     * @param radio
     * @return
     */
    this.orderRadio = function(callback, radioPosition){
        var params = {
            radio: {radioPosition: radioPosition}
        };
        $mqDao(this.queueName, 'orderRadio', params, function(msg){
            callback(msg);
        });
    };

    /**
     * 在线支付请求订单数据
     * @param callback 回调函数
     * @param orderId 订单Id
     */
    this.orderOnlinePay = function(callback, orderId){
        var params = {
            orderId: orderId
        };
        $mqDao(this.queueName, 'orderOnlinePay', params, function(msg) {
            callback(msg);
        });
    };

    /**
     * 订单跟踪状态
     * @param callback
     * @param orderId   订单Id
     */
    this.getOrderTrackingAndStatus = function(callback, orderId){
        var params = {
            orderId: orderId
        };
        $mqDao(this.queueName, 'getOrderTrackingAndStatus', params, function(msg) {
            callback(msg);
        });
    };

    /**
     * 订单跟踪状态 第二版 总订单
     * @param callback
     * @param orderId   订单Id
     */
    this.getBossOrderTrackingAndStatus = function(callback, orderId){
        var params = {
            bossOrderNum: orderId
        };
        $mqDao(this.queueName, 'getBossOrderTrackingAndStatus', params, function(msg) {
            callback(msg||{});
        });
    };

    /**
     * 订单跟踪状态 第二版 子订单
     * @param callback
     * @param orderId   订单Id
     */
    this.queryBossOrderTrackingAndStatus = function(callback, orderId){
        var params = {
            bossOrderNum: orderId
        };
        $mqDao(this.queueName, 'queryBossOrderTrackingAndStatus', params, function(msg) {
            callback(msg||{});
        });
    };

    /**
     * 微信支付请求参数
     * @param callback  回调函数
     * @param orderId     订单Id
     */
    this.weChatUnifiedPay = function(callback, orderId){
        var params = {
            orderId: orderId,
            appId: appEnvironment
        };
        $mqDao(this.queueName, 'weChatUnifiedPay', params, function(msg) {
            callback(msg);
        });
    };

    /**
     * 微信支付同步请求
     * @param callback  回调函数
     * @param orderNum     订单号
     */
    this.wxOnlinePayInfoSynchronous = function(callback, orderNum){
        var params = {
    		payInfo: "success",
        	orderNum: orderNum,
        	appId: appEnvironment
        };
        $mqDao(this.queueName, 'wxOnlinePayInfoSynchronous', params, function(msg) {
            callback(msg);
        });
    };

    /**
     * 支付宝支付请求参数
     * @param callback  回调函数
     * @param orderId     订单Id
     */
    this.queryAlipayOrderInfo = function(callback, orderId){
        var params = {
            orderId: orderId
        };
        $mqDao(this.queueName, 'queryAlipayOrderInfo', params, function(msg) {
            callback(msg);
        });
    };

    /**
     * 支付宝同步返回接口
     */
    this.onlinePayInfoSynchronous = function(callback, params){
        $mqDao(this.queueName, 'onlinePayInfoSynchronous', params, function(msg) {
            callback(msg);
        });
    };

    /**
     * 获取当前订单列表
     * @param orderMobile 下单电话
     * @param pageNum 当前第几页
     * @return
     */
    // public List<Map<String, Object>> queryTodayOrderList( String orderMobile, int pageNum ){
    //     return queryOrderList(orderMobile, 1, pageNum);
    // }
    this.queryTodayOrderList = function(callback, mobile, page){
        var params = {
            orderMobile: mobile || '',
            pageNum: page.getCurrentPage()
        };
        $mqDao(this.queueName, 'queryTodayOrderList', params, function(msg) {
            var result = [];
            if(msg && msg.length){
                result = msg;
            }
            callback(result);
            page.updateCurrentPage();
        });
    };

    /**
     * 获取历史订单列表
     * @param orderMobile 下单电话
     * @param pageNum 当前第几页
     * @return
     */
    // public List<Map<String, Object>> queryHistoryOrderList( String orderMobile, int pageNum ){
    //     return queryOrderList(orderMobile, 0, pageNum);
    // }
    this.queryHistoryOrderList = function(callback, mobile, page){
        var params = {
            orderMobile: mobile || '',
            pageNum: page.getCurrentPage()
        };
        $mqDao(this.queueName, 'queryHistoryOrderList', params, function(msg) {
            var result = [];
            if(msg && msg.length){
                result = msg;
            }
            callback(result);
            page.updateCurrentPage();
        });
    };

    /**
     * 添加投诉建议
     * @param mobile 投诉电话
     * @param complain 投诉建议
     * @param orderId 订单id
     * @return
     */
    // @IsMqFunction(paramNames={"mobile", "complain=", "orderId"})
    // public ResultMap addComplain(String mobile, String complain, int orderId);
    this.addComplain = function(callback, mobile, complain, orderId){
        var params = {
            mobile: mobile || '',
            complain: complain || '',
            orderId: parseInt(orderId)
        };
        $mqDao(this.queueName, 'addComplain', params, function(msg) {
            var result = {};
            if(msg){
                result = msg;
            }
            callback(result);
        });
    };


    /**
     * 获取用户当前订单可用积分及抵扣金额
     * @param mobile 用户账号
     * @param hefenGoodsMoney 自营商品金额合计
     * @return {"consumePoint":120.00,"userPointMoney":0.12}
     */
    // @IsMqFunction(paramNames={"mobile","hefenGoodsMoney"})
    // ResultMap userPointToMoney(String mobile, double hefenGoodsMoney);
    this.userPointToMoney = function(callback, mobile, money){
        var params = {
            mobile: mobile || '',
            hefenGoodsMoney: parseFloat(money) || 0
        };
        $mqDao(this.queueName, 'userPointToMoney', params, function(msg) {
            var result = {};
            if(msg){
                result = msg;
            }
            callback(result);
        });
    };

    /**
     * 获取用户不同订单状各自的数量
     * @param userMobile
     * @return
     * {    resultMsg=查询成功, resultCode=success,
     *  resultTO={"waitPay":15,"waitDeliver":12,"waitFetch":45,"waitEvaluate"}
     * }
     * @IsMqFunction(paramNames={"userMobile"})
     ResultMap queryOrderStausCount(String userMobile);
     */
    this.queryOrderStatusCount=function(callback,userMobile){
        var params={
          userMobile:userMobile||''
        };
        $mqDao(this.queueName,'queryOrderStatusCount',params,function(data){
            var result={};
            if(data){
                result=data;
            }
            callback(result);
        });
    };

    /**
     * 通过订单状态查询订单
     * @param userMobile 用户手机号
     * @param orderStatus 订单状态(allOrder:全部订单,waitPay:待付款,waitDeliver:待发货,waitFetch:待收货,waitEvaluate:待评价)
     * @param pageNum 页码
     * @param pageSize 页长
     * @return
     */
      this.queryOrderByOrderStatus=function(callback,userMobile,orderStatus,page){
          var params={
              userMobile:userMobile||'',
              orderStatus:orderStatus||'',
              pageNum: page.getCurrentPage()||''
          };
          $mqDao(this.queueName,'queryOrderByOrderStatus',params,function(data){
              var result={};
              if(data){
                  result=data;
              }
              callback(result);
              page.updateCurrentPage();
          });
      };

    /**
     * 获取用户当前订单可用积分及抵扣金额
     * @param mobile 用户账号
     * @param shopBrandGoodsMoney 按供应商分组的商品金额合计。{供应商id:合计金额}
     * @return {"consumePoint":120.00,"userPointMoney":1.20,"detail":{"308":{"point":110,"pointMoney":1.10}}}
     */
    // @IsMqFunction(paramNames={"mobile","shopBrandGoodsMoney"})
    // ResultMap userPointMoneyByShopBrand(String mobile, JSONObject shopBrandGoodsMoney);
    this.userPointMoneyByShopBrand = function(callback, phone, info){
        var params={
              mobile: phone||'',
              shopBrandGoodsMoney: info||{},
          };
          $mqDao(this.queueName,'userPointMoneyByShopBrand',params,function(msg){
              var result={};
              if(msg){
                  result=msg;
              }
              callback(result);
          });
    };
}]);
