app.service('shopBrandService', ['$mqDao', function($mqDao){
    this.queueName = 'app_shop_brand_service';
    /**
     * 注意，所有接口方法需要执行callback()方法，即使返回空数组[]空对象{}，因为要隐藏页面中的Loading弹窗
     */

    /**
     * 查询供应商列表
     * @param callback
     * @param position 用户定位
     * @param categoryId   顶级分类Id
     * @param subCategoryId  二级分类Id
     * @param orderBy  排序
     * @param page     分页对象
     * @return
     */
    this.queryShopBrandList = function(callback, position, categoryFirstId, categoryPId, categoryId, orderBy, page){
        var params = {
            pageInfo: {pageNum: page.getCurrentPage()},
            shopBrandInfo: {
                shopBrandCategoryFirstId: categoryFirstId==null ? null : parseInt(categoryFirstId),
                shopBrandCategoryPId: categoryPId==null ? null : parseInt(categoryPId),
                shopBrandCategoryId: categoryId==null ? null : parseInt(categoryId),
                shopBrandSort: orderBy.toString(),
                userLongitude: parseFloat(position.lon||0),
                userLatitude: parseFloat(position.lat||0)
            }
        };
        $mqDao(this.queueName, 'queryShopBrandList', params, function(msg){
            var data = [];
            angular.forEach(msg, function( shop, i){
                shop.shopImgUrl = parseImgUrlNew(shop.shopBrandImgUrl, 'small');
                shop.shopBrandStarNum = parseInt(shop.shopBrandStarNum);
                data.push(shop);
            });

            callback(data);
            page.updateCurrentPage();
        });
    };

    this.queryShopBrandListCommunity = function(callback, communityId, categoryFirstId, categoryPId, categoryId, orderBy, page){
        var params = {
            pageInfo: {pageNum: page.getCurrentPage()},
            shopBrandInfo: {
                shopBrandCategoryFirstId: categoryFirstId==null ? null : parseInt(categoryFirstId),
                shopBrandCategoryPId: categoryPId==null ? null : parseInt(categoryPId),
                shopBrandCategoryId: categoryId==null ? null : parseInt(categoryId),
                shopBrandSort: orderBy.toString()
            },
            communityId: parseInt(communityId) || 0
        };
        $mqDao(this.queueName, 'queryShopBrandListCommunity', params, function(msg){
            // console.log('结果',msg);
            var data = [];
            angular.forEach(msg, function( shop, i){
                shop.shopImgUrl = parseImgUrlNew(shop.shopBrandImgUrl, 'small');
                shop.shopBrandStarNum = parseInt(shop.shopBrandStarNum);
                // var pp = [
                //     {promotionId:234, promotionName:'促销氢气球', promotionTerm: {promotionType:1,priceDown:3}},
                //     {promotionId:235, promotionName:'满减参加考试', promotionTerm: {promotionType:4,priceDown:8,priceReach: 39}}
                // ];
                shop.shopBrandPromotion = parsePromotionForShopBrand(shop.shopBrandPromotion);
                data.push(shop);
            });

            callback(data);
            page.updateCurrentPage();
        });
    };

    /**
     * 查询供应商品类列表（以废弃，请转到 this.queryShopBrandCategoryListByCommunity ）
     * @param categoryId 顶级分类Id
     * @return
     */
    this.queryShopBrandCategoryList = function(callback, categoryId){
        var params = {
            shopCustomCategory: {
                shopCustomCategoryPlatformCategory:{
                    categoryFirstId: parseInt(categoryId)
                }
            }
        };
        $mqDao(this.queueName, 'queryShopBrandCategoryList', params, function(msg){
            callback(parseCategory(msg));
        });
    };

    /**
     * 查询供应商信息
     * @param shopBrand
     * @return
     */
    // @IsMqFunction(paramNames={"shopBrand"})
    // public Map<String, Object> queryShopBrandDetails(Map<String, Object> shopBrand);
    this.queryShopBrandDetails = function(callback, shopBrandId){
        var params = {
            shopBrand: {
                shopBrandId: shopBrandId
            }
        };
        $mqDao(this.queueName, 'queryShopBrandDetails', params, function(msg){
            callback(msg);
        });
    };

    /**
     * 获取供货商（店铺）列表页面的分类
     * @param callback
     * @param communityId 定位的小区ID
     * @param categoryFirstId 第一级品类ID
     * @param categoryPId 第二级品类ID
     * @param categoryId 第三级品类ID
     * @return Array 店铺列表
     */
    this.queryShopBrandCategoryListByCommunity = function(callback, communityId, categoryFirstId, categoryPId, categoryId){
        var params = {
            shopBrandInfo: {
                shopBrandCategoryFirstId: categoryFirstId==null ? null : parseInt(categoryFirstId),
                shopBrandCategoryPId: categoryPId==null ? null : parseInt(categoryPId),
                shopBrandCategoryId: categoryId==null ? null : parseInt(categoryId)
            },
            communityId: parseInt(communityId) || 0
        };
        $mqDao(this.queueName, 'queryShopBrandCategoryListByCommunity', params, function(msg){
            // console.log(msg);
            var result = [];
            if(msg && msg.length){
                result = parseCategory(msg);
            }
            callback(result);
        });
    };

}]);

