app.service('userService', ['$mqDao', function($mqDao) {
    this.queueName = 'app_user_service';
    /**
     * 注意，所有接口方法需要执行callback()方法，即使返回空数组[]空对象{}，因为要隐藏页面中的Loading弹窗
     */

    /**
     * 已注册用户登陆
     * @param callback
     * @param phone 用户电话
     * @param password 密码
     * @return 状态信息，状态码
     * {"msg":"登陆成功","status":4}
     * 账号或密码为空：1，此用户不存在：2，密码错误：3，登陆成功：4
     */
    this.userLanding = function(callback, phone, password) {
        var params = {
            mobile: phone,
            password: password
        };
        $mqDao(this.queueName, 'userLanding', params, function(data) {
            callback(data);
        });
    };


    /**
     * 用户注册
     * @param callback
     * @param phone 手机号
     * @param password 密码
     * @param recommender 推荐人 默认为空串
     * @return  用户电话或密码为空：-3，推荐人电话错误或未注册 ：-2，用户已存在：-1， 添加失败： 0， 添加成功：1
     */
    this.addUser = function(callback, phone, password, recommender) {
        var params = {
            mobile: phone,
            password: password,
            recommendUserMobile: recommender
        };
        $mqDao(this.queueName, 'addUser', params, function(data) {
            callback(data);
        });
    };

    /**
     * 查询用户是否已注册
     * @param callback
     * @param phone 用户电话
     * @return 未注册：0,已注册：大于0的值
     */
    this.checkMobileExist = function(callback, phone) {
        var params = {
            mobile: phone
        };
        $mqDao(this.queueName, 'checkMobileExist', params, function(data) {
            callback(data);
        });
    };


    /**
     * 发送验证码
     * @param phone 用户手机号
     * @param callback
     * @return 失败时返回-1，成功时返回五位数字的验证码
     */
    this.sendVCode = function(callback, phone) {
        var params = {
            mobile: phone
        };
        $mqDao(this.queueName, 'sendVCode', params, function(data) {
            callback(data);
        });
    };

    /**
     * 获取用户地址列表
     * @param callback
     * @param phone 用户手机号
     * @return
     */
    this.queryUserAddressByUserTable = function(callback, phone) {
        var params = {
            userMobile: phone
        };
        //queryUserAddressByUserTable
        var method = queryUserAddressByUserTableMap[appEnvironment];
        $mqDao(this.queueName, method, params, function(data) {
            if (!data.defaultAddress) {
                data.defaultAddress = {};
            }
            callback(data);
        });
    };

    /**
     * 修改用户默认地址
     * @param callback
     * @param userMobile    用户电话
     * @param addressId     地址Id
     * @return 成功返回 1
     */
    this.updateUserDefaultAddress = function(callback, userMobile, addressId) {
        var params = {
            userMobile: userMobile,
            addressId: addressId
        };
        //updateUserDefaultAddress
        var method = updateUserDefaultAddressMap[appEnvironment];
        $mqDao(this.queueName, method, params, function(data) {
            callback(data);
        });
    };

    /**
     * 增加收货地址
     * @param callback          回调函数
     * @param userMobile        用户电话
     * @param addressLinkTel    收货人电话
     * @param addressLinkMen    收货人姓名
     * @param communityName     小区名称
     * @param communityId       小区Id
     * @param addressContent    详细地址
     * @param buildingId        楼号Id（当为校园版时需要）
     * @param buildingName      楼号名称（当为校园版时需要）
     * @return address_id =0 (插入地址) -->  返回address_id
     */
    this.addUserAddress = function(callback, userMobile, addressLinkTel, addressLinkMen, communityName, communityId, addressContent, buildingId, buildingName) {
        var params = {
            userMobile: userMobile,
            addressLinkTel: addressLinkTel,
            addressLinkMen: addressLinkMen,
            communityName: communityName,
            communityId: communityId,
            addressContent: addressContent
        };
        if (!currentEnvironment()) {
            params.buildingId = buildingId;
            params.buildingName = buildingName;
            //          params.addressContent = buildingName+""+addressContent;
        }
        //addUserAddress
        var method = addUserAddressMap[appEnvironment];
        $mqDao(this.queueName, method, params, function(data) {
            callback(data);
        });
    };

    /**
     * 修改收货地址
     * @param callback          回调函数
     * @param addressId         修改地址Id
     * @param userMobile        用户电话
     * @param addressLinkTel    收货人电话
     * @param addressLinkMen    收货人姓名
     * @param communityName     小区名称
     * @param communityId       小区Id
     * @param addressContent    详细地址
     * @param buildingId        楼号Id（当为校园版时需要）
     * @param buildingName      楼号名称（当为校园版时需要）
     * @return address_id =0 (插入地址) -->  返回address_id
     *         address_id!=0 (修改地址) -->  成功1  失败 0
     */
    this.updateUserAddress = function(callback, addressId, userMobile, addressLinkTel, addressLinkMen, communityName, communityId, addressContent, buildingId, buildingName) {
        var params = {
            addressId: addressId,
            userMobile: userMobile,
            addressLinkTel: addressLinkTel,
            addressLinkMen: addressLinkMen,
            communityName: communityName,
            communityId: 0, //这里因为用户地址列表没有communityId所以修改的时候默认为0
            addressContent: addressContent,
            addressStatus: 1
        };
        if (!currentEnvironment()) {
            params.buildingId = buildingId;
            params.buildingName = buildingName;
            params.communityId = communityId;
            //          params.addressContent = buildingName+""+addressContent;
        }
        //updateUserAddress
        var method = updateUserAddressMap[appEnvironment];
        $mqDao(this.queueName, method, params, function(data) {
            callback(data);
        });
    };

    /**
     * 删除收货地址
     * @param callback      回调函数
     * @param addressId     收货地址Id
     * @return 1 成功 0 失败
     */
    this.deleteUserAddressByAddressId = function(callback, addressId) {
        var params = {
            addressId: addressId
        };
        //deleteUserAddressByAddressId
        var method = deleteUserAddressByAddressIdMap[appEnvironment];
        $mqDao(this.queueName, method, params, function(data) {
            callback(data);
        });
    };

    /**
     * 获取小区列表
     * @param callback      回调函数
     * @param communityName 小区名称
     * @return ［ ｛ommunityId:1,communityName:"佳远水园湾"｝ ］
     * communityId-小区／单位ID,communityName-小区/单位名称，communityAddress－小区地址，communityArea－小区区域，communityStreet－街道
     */
    this.getCommunity = function(callback, communityName) {
        var params = {
            communityName: communityName
        };
        $mqDao(this.queueName, 'getCommunity', params, function(data) {
            callback(data);
        });
    };

    /**
     * 查询用户密码，直接发送到手机号
     * @param callback
     * @param mobile
     */
    this.queryUserPassword = function(callback, mobile) {

        var params = {
            userInfo: {
                mobile: mobile
            }
        };
        // callback({
        //     resultCode: 'success'
        // });
        $mqDao(this.queueName, 'queryUserPassword', params, function(data) {
            callback(data);
        });
    };


    /**
     * 修改用户密码
     * @param userInfo {mobile:'',password:''}
     */
    this.changeUserPassword = function(callback, mobile, password) {
        var params = {
            userInfo: {
                mobile: mobile,
                password: password
            }
        };
        // var data = {resultCode:'success',resultMsg:'修改成功！'};
        // var data2 = {resultCode:'faild',resultMsg:'修改失败！'};
        // callback(data2);
        $mqDao(this.queueName, 'changeUserPassword', params, function(data) {
            callback(data);
        });
    };

    /**
     * 获取按用户位置附近的小区。
     * @param userLon 用户位置
     * @param userLat 用户位置
     * @return
     */
    this.getPositionCommunity = function(callback, lat, lon) {
        var params = {
            userLat: parseFloat(lat) || 0,
            userLon: parseFloat(lon) || 0
        };
        //getPositionCommunity
        var method = getPositionCommunityMap[appEnvironment];
        $mqDao(this.queueName, method, params, function(data) {
            var result = {};
            result.nearCommunityList = [];
            result.locationCommunity = {};
            if (data.nearCommunityList && data.nearCommunityList.length) {
                result.nearCommunityList = data.nearCommunityList;
            }
            if (data.locationCommunity && Object.keys(data.locationCommunity).length) {
                result.locationCommunity = data.locationCommunity;
            }
            callback(result);
        });
    };

    /**
     * 获取按用户位置百度坐标附近的小区。
     * @param userLon 用户位置
     * @param userLat 用户位置
     * @return
     */
    this.getBdPositionCommunity = function(callback, lat, lon) {
        var params = {
            userLat: parseFloat(lat) || 0,
            userLon: parseFloat(lon) || 0
        };
        //getBdPositionCommunity
        var method = getBdPositionCommunityMap[appEnvironment];
        $mqDao(this.queueName, method, params, function(data) {
            var result = {};
            result.nearCommunityList = [];
            result.locationCommunity = {};
            if (data.nearCommunityList && data.nearCommunityList.length) {
                result.nearCommunityList = data.nearCommunityList;
            }
            if (data.locationCommunity && Object.keys(data.locationCommunity).length) {
                result.locationCommunity = data.locationCommunity;
            }
            callback(result);
        });
    };

    /**
     * 获取用户小区历史记录。包含用户的收货地址和小区搜索历史
     * @param userMobile
     * @return
     * [{"communityId":1,"communityName":"佳远水园湾","orderNum":0,"userDistance":99999 ,"userDistanceStr":"33千米"}]
     */

    this.getUserCommunityHistory = function(callback, mobile) {
        var params = {
            userMobile: mobile
        };
        //getUserCommunityHistory
        var method = getUserCommunityHistoryMap[appEnvironment];
        $mqDao(this.queueName, method, params, function(data) {
            var result = [];
            if (data && data.length) {
                result = data;
            }
            callback(result);
        });
    };

    /**
     * 获取按用户位置附近的小区。
     * @param userLon 用户位置
     * @param userLat 用户位置
     * @param shopIdList 店铺id列表
     * @return
     */
    this.queryPositionCommunity = function(callback, lat, lon, shopIdList) {
        var params = {
            userLat: parseFloat(lat) || 0,
            userLon: parseFloat(lon) || 0,
            shopIdList: shopIdList
        };
        //queryPositionCommunity
        var method = queryPositionCommunityMap[appEnvironment];
        $mqDao(this.queueName, method, params, function(data) {
            var result = {};
            result.nearCommunityList = [];
            result.locationCommunity = {};
            if (data.nearCommunityList && data.nearCommunityList.length) {
                result.nearCommunityList = data.nearCommunityList;
            }
            if (data.locationCommunity && Object.keys(data.locationCommunity).length) {
                result.locationCommunity = data.locationCommunity;
            }
            callback(result);
        });
    };

    /**
     * 获取按用户位置百度坐标附近的小区。
     * @param userLon 用户位置
     * @param userLat 用户位置
     * @param shopIdList 店铺id列表
     * @return
     */
    this.queryBdPositionCommunity = function(callback, lat, lon, shopIdList) {
        var params = {
            userLat: parseFloat(lat) || 0,
            userLon: parseFloat(lon) || 0,
            shopIdList: shopIdList
        };
        //queryBdPositionCommunityMap
        var method = queryBdPositionCommunityMap[appEnvironment];
        $mqDao(this.queueName, method, params, function(data) {
            var result = {};
            result.nearCommunityList = [];
            result.locationCommunity = {};
            if (data.nearCommunityList && data.nearCommunityList.length) {
                result.nearCommunityList = data.nearCommunityList;
            }
            if (data.locationCommunity && Object.keys(data.locationCommunity).length) {
                result.locationCommunity = data.locationCommunity;
            }
            callback(result);
        });
    };

    /**
     * 获取用户小区历史记录。包含用户的收货地址和小区搜索历史
     * @param userMobile
     * @param shopIdList 店铺id列表
     * @return
     * [{"communityId":1,"communityName":"佳远水园湾","orderNum":0,"userDistance":99999 ,"userDistanceStr":"33千米"}]
     */

    this.queryUserCommunityHistory = function(callback, mobile, shopIdList) {
        var params = {
            userMobile: mobile,
            shopIdList: shopIdList
        };
        //queryUserCommunityHistory
        var method = queryUserCommunityHistoryMap[appEnvironment];
        $mqDao(this.queueName, method, params, function(data) {
            var result = [];
            if (data && data.length) {
                result = data;
            }
            callback(result);
        });
    };




    /**
     * 获取小区中楼号列表
     * @param callback      回调函数
     * @param communityId   小区id
     * @return 楼号列表。空数组
     */
    this.getBuildingListByCommunityId = function(callback, communityId) {
        var params = {
            communityId: communityId
        };
        $mqDao(this.queueName, 'getBuildingListByCommunityId', params, function(data) {
            var result = [];
            if (data && data.length) {
                result = data;
            }
            callback(result);
        });
    };

    /**
     * 获取服务器时间
     * @param  {Function} callback 回调函数
     * @return
     */
    this.getServerTimeStamp = function(callback) {
        $mqDao(this.queueName, 'getServerTimeStamp', {}, function(data) {
            var result = 0;
            if (data) {
                result = data;
            }
            callback(result);
        });
    };

    /**
     * 发送验证码
     * @param mobile
     * @param count  第几次发送验证码
     * @param flag  ==> login | regist
     * @return 0  倒计时（120）
     *         >0 倒计时（n）
     */
    this.sendVerCode = function(callback, mobile, count, flag) {
        var params = {
            mobile: mobile || '',
            count: count || 0,
            flag: flag || ''
        };
        $mqDao(this.queueName, 'sendVerCode', params, function(data) {
            var result = -1;
            if (data >= 0) {
                result = data;
            }
            callback(result);
        });
    };
    /**
     * 校验验证码
     * @param mobile
     * @param vcode
     * @param flag  ==> login | regist
     * @return {resultMsg:'',resultCode:0}
     *         {resultMsg:'',resultCode:1}
     */
    this.checkVerCode = function(callback, mobile, code, flag) {
        var params = {
            mobile: mobile || '',
            vcode: code || '',
            flag: flag || ''
        };
        $mqDao(this.queueName, 'checkVerCode', params, function(data) {
            var result = {};
            if (data) {
                result = data;
            }
            callback(result);
        });
    };
    /**
     * 获取用户积分详细
     * @param userMobile 用户手机号
     * @param pageNum 页码
     * @param pageSize 页长
     * @return
     * {resultMsg=查询成功, resultCode=success, resultTO={"pointDetail":[{"pointEvent":"国庆荷粉大放送","pointMobile":"18203221346","pointNumber":100,"pointTime":"2016-08-31 11:44:29"},{"pointEvent":"订单折扣","pointMobile":"18203221346","pointNumber":-10,"pointOrderNumApp":"HF1510250212945","pointTime":"2016-08-31 11:43:23"},{"pointEvent":"购物送豆","pointMobile":"18203221346","pointNumber":10,"pointTime":"2016-08-31 11:39:11"}],"restPoint":300}}

     *@IsMqFunction(paramNames={"userMobile"})
     public ResultMap getPoint(String userMobile);
     final static String SERVICE_NAME = "app_user_service";
     */
    this.getPoint = function(callback, userMobile, page) {
        var params = {
            userMobile: userMobile || '',
            pageNum: page.getCurrentPage() || 1,
            pageSize: page.getPerPage() || 1
        };
        $mqDao(this.queueName, 'getUserPointDetail', params, function(data) {
            var result = {};
            if (data) {
                result = data;
            }
            callback(result);
            page.updateCurrentPage();
        });
    };


    /**
     * 获取默认的小区列表。随机取50个小区
     * @return
     */
    // @IsMqFunction(paramNames={})
    // public ResultMap defaultCommunityList();
    this.defaultCommunityList = function(callback){

        $mqDao(this.queueName, 'defaultCommunityList', {}, function(data) {
            callback(data);
        });
    };
}]);
